@@ -36,9 +36,13 @@ public abstract class DMNModelInstrumentedBase implements DMNDefinition {
     @Portable
     public enum Namespace {
 
-        FEEL("feel", org.kie.dmn.model.v1_1.DMNModelInstrumentedBase.URI_FEEL),
-        DMN("dmn", org.kie.dmn.model.v1_1.DMNModelInstrumentedBase.URI_DMN),
-        KIE("kie", org.kie.dmn.model.v1_1.DMNModelInstrumentedBase.URI_KIE);
+        FEEL("feel", org.kie.dmn.model.v1_2.KieDMNModelInstrumentedBase.URI_FEEL),
+        DMN("dmn", org.kie.dmn.model.v1_2.KieDMNModelInstrumentedBase.URI_DMN),
+        KIE("kie", org.kie.dmn.model.v1_2.KieDMNModelInstrumentedBase.URI_KIE),
+        DEFAULT(QName.DEFAULT_NS_PREFIX, "https://kiegroup.org/dmn/"),
+        DMNDI("dmndi", org.kie.dmn.model.v1_2.KieDMNModelInstrumentedBase.URI_DMNDI),
+        DI("di", org.kie.dmn.model.v1_2.KieDMNModelInstrumentedBase.URI_DI),
+        DC("dc", org.kie.dmn.model.v1_2.KieDMNModelInstrumentedBase.URI_DC);
 
         private String prefix;
         private String uri;
