@@ -17,9 +17,9 @@ package org.kie.workbench.common.dmn.api.property.dmn;
 
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.kie.soup.commons.validation.PortablePreconditions;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase.Namespace;
 import org.kie.workbench.common.dmn.api.property.DMNProperty;
 import org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType;
+import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @Portable
 public class QName implements DMNProperty {
@@ -28,15 +28,20 @@ public class QName implements DMNProperty {
 
     public static final String DEFAULT_NS_PREFIX = "";
 
-    private String namespaceURI;
+    private final String namespaceURI;
 
-    private String localPart;
+    private final String localPart;
 
-    private String prefix;
+    private final String prefix;
 
     public QName() {
-        this(Namespace.FEEL.getUri(),
-             BuiltInType.STRING.getName());
+        this(NULL_NS_URI,
+             BuiltInType.UNDEFINED.getName());
+    }
+
+    public QName(final BuiltInType type) {
+        this(NULL_NS_URI,
+             type.getName());
     }
 
     public QName(final String namespaceURI,
@@ -94,7 +99,7 @@ public class QName implements DMNProperty {
             return false;
         }
 
-        QName qName = (QName) o;
+        final QName qName = (QName) o;
 
         if (!namespaceURI.equals(qName.namespaceURI)) {
             return false;
@@ -107,10 +112,7 @@ public class QName implements DMNProperty {
      */
     @Override
     public int hashCode() {
-        int result = namespaceURI.hashCode();
-        result = ~~result;
-        result = 31 * result + localPart.hashCode();
-        result = ~~result;
-        return result;
+        return HashUtil.combineHashCodes(namespaceURI.hashCode(),
+                                         localPart.hashCode());
     }
-}
+}
\ No newline at end of file
