@@ -29,51 +29,58 @@ import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Context;
 import org.kie.workbench.common.dmn.api.definition.v1_1.ContextEntry;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
 import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.context.AddContextEntryCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.context.ClearExpressionTypeCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.context.DeleteContextEntryCommand;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.editors.expressions.util.SelectionUtils;
+import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGridRenderer;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.HasRowDragRestrictions;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
+import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
+import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
 import org.uberfire.ext.wires.core.grids.client.widget.dnd.GridWidgetDnDHandlersState;
 import org.uberfire.ext.wires.core.grids.client.widget.dnd.GridWidgetDnDHandlersState.GridWidgetHandlersOperation;
-import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
 public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, ContextUIModelMapper> implements HasRowDragRestrictions,
                                                                                                                HasListSelectorControl {
 
-    private static final String EXPRESSION_COLUMN_GROUP = "ContextGrid$ExpressionColumn1";
-
     private final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private final NameAndDataTypePopoverView.Presenter headerEditor;
 
     public ContextGrid(final GridCellTuple parent,
                        final Optional<String> nodeUUID,
                        final HasExpression hasExpression,
-                       final Optional<Context> expression,
                        final Optional<HasName> hasName,
                        final DMNGridPanel gridPanel,
                        final DMNGridLayer gridLayer,
@@ -81,32 +88,39 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
                        final DefinitionUtils definitionUtils,
                        final SessionManager sessionManager,
                        final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                       final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                       final DefaultCanvasCommandFactory canvasCommandFactory,
                        final Event<ExpressionEditorChanged> editorSelectedEvent,
+                       final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                       final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                        final CellEditorControlsView.Presenter cellEditorControls,
                        final ListSelectorView.Presenter listSelector,
                        final TranslationService translationService,
+                       final boolean isOnlyVisualChangeAllowed,
                        final int nesting,
-                       final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
+                       final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
+                       final NameAndDataTypePopoverView.Presenter headerEditor) {
         super(parent,
               nodeUUID,
               hasExpression,
-              expression,
               hasName,
               gridPanel,
               gridLayer,
               gridData,
-              new ContextGridRenderer(nesting > 0),
+              new BaseExpressionGridRenderer(gridData),
               definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               cellEditorControls,
               listSelector,
               translationService,
+              isOnlyVisualChangeAllowed,
               nesting);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
+        this.headerEditor = headerEditor;
 
         setEventPropagationMode(EventPropagationMode.NO_ANCESTORS);
 
@@ -123,7 +137,8 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
     public ContextUIModelMapper makeUiModelMapper() {
         return new ContextUIModelMapper(this,
                                         this::getModel,
-                                        () -> expression,
+                                        getExpression(),
+                                        () -> isOnlyVisualChangeAllowed,
                                         expressionEditorDefinitionsSupplier,
                                         listSelector,
                                         nesting);
@@ -131,17 +146,40 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
 
     @Override
     public void initialiseUiColumns() {
-        final NameColumn nameColumn = new NameColumn(new NameColumnHeaderMetaData(() -> hasName.orElse(HasName.NOP).getName().getValue(),
-                                                                                  (s) -> hasName.orElse(HasName.NOP).getName().setValue(s),
-                                                                                  getHeaderHasNameTextBoxFactory()),
-                                                     getBodyTextBoxFactory(),
-                                                     this);
+        final List<GridColumn.HeaderMetaData> headerMetaData = new ArrayList<>();
+        final ContextGridRowNumberColumn rowNumberColumn = new ContextGridRowNumberColumn(headerMetaData,
+                                                                                          getAndSetInitialWidth(0, ContextGridRowNumberColumn.DEFAULT_WIDTH));
+        if (nesting == 0) {
+            rowNumberColumn.getHeaderMetaData().add(new BaseHeaderMetaData("#"));
+            headerMetaData.add(new NameColumnHeaderMetaData(hasExpression,
+                                                            hasName,
+                                                            clearDisplayNameConsumer(true),
+                                                            setDisplayNameConsumer(true),
+                                                            setTypeRefConsumer(),
+                                                            cellEditorControls,
+                                                            headerEditor,
+                                                            Optional.of(translationService.getTranslation(DMNEditorConstants.ContextEditor_EditExpression)),
+                                                            listSelector,
+                                                            this::getHeaderItems,
+                                                            this::onItemSelected));
+        }
+
+        final NameColumn nameColumn = new NameColumn(headerMetaData,
+                                                     getAndSetInitialWidth(1, DMNGridColumn.DEFAULT_WIDTH),
+                                                     this,
+                                                     (rowIndex) -> rowIndex != getModel().getRowCount() - 1,
+                                                     clearDisplayNameConsumer(false),
+                                                     setDisplayNameConsumer(false),
+                                                     setTypeRefConsumer(),
+                                                     cellEditorControls,
+                                                     headerEditor,
+                                                     Optional.of(translationService.getTranslation(DMNEditorConstants.ContextEditor_EditContextEntry)));
         final ExpressionEditorColumn expressionColumn = new ExpressionEditorColumn(gridLayer,
-                                                                                   new BaseHeaderMetaData("",
-                                                                                                          EXPRESSION_COLUMN_GROUP),
+                                                                                   headerMetaData,
+                                                                                   getAndSetInitialWidth(2, UndefinedExpressionColumn.DEFAULT_WIDTH),
                                                                                    this);
 
-        model.appendColumn(new RowNumberColumn());
+        model.appendColumn(rowNumberColumn);
         model.appendColumn(nameColumn);
         model.appendColumn(expressionColumn);
 
@@ -150,9 +188,9 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
 
     @Override
     public void initialiseUiModel() {
-        expression.ifPresent(c -> {
+        getExpression().get().ifPresent(c -> {
             c.getContextEntry().stream().forEach(ce -> {
-                model.appendRow(new DMNGridRow());
+                model.appendRow(new ExpressionEditorGridRow());
                 uiModelMapper.fromDMNModel(model.getRowCount() - 1,
                                            0);
                 uiModelMapper.fromDMNModel(model.getRowCount() - 1,
@@ -163,11 +201,6 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
         });
     }
 
-    @Override
-    protected boolean isHeaderHidden() {
-        return nesting > 0;
-    }
-
     @Override
     public boolean isRowDragPermitted(final GridWidgetDnDHandlersState state) {
         final GridWidgetHandlersOperation operation = state.getOperation();
@@ -179,36 +212,51 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
         return true;
     }
 
+    @SuppressWarnings("unused")
+    List<ListSelectorItem> getHeaderItems(final int uiHeaderRowIndex,
+                                          final int uiHeaderColumnIndex) {
+        final List<ListSelectorItem> items = new ArrayList<>();
+
+        items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.ContextEditor_Header)));
+        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_InsertContextEntry),
+                                             true,
+                                             () -> {
+                                                 cellEditorControls.hide();
+                                                 getExpression().get().ifPresent(e -> addContextEntry(model.getRowCount() - 1));
+                                             }));
+
+        return items;
+    }
+
     @Override
     @SuppressWarnings("unused")
     public List<ListSelectorItem> getItems(final int uiRowIndex,
                                            final int uiColumnIndex) {
         final List<ListSelectorItem> items = new ArrayList<>();
-        if (uiRowIndex == model.getRowCount() - 1) {
-            return items;
-        }
-
         final boolean isMultiRow = SelectionUtils.isMultiRow(model);
         final boolean isMultiSelect = SelectionUtils.isMultiSelect(model);
 
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_InsertContextEntryAbove),
-                                             !isMultiRow,
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addContextEntry(uiRowIndex));
-                                             }));
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_InsertContextEntryBelow),
-                                             !isMultiRow,
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addContextEntry(uiRowIndex + 1));
-                                             }));
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_DeleteContextEntry),
-                                             !isMultiRow && model.getRowCount() > 2 && uiRowIndex < model.getRowCount() - 1,
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 deleteContextEntry(uiRowIndex);
-                                             }));
+        if (uiRowIndex < model.getRowCount() - 1) {
+            items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.ContextEditor_Header)));
+            items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_InsertContextEntryAbove),
+                                                 !isMultiRow,
+                                                 () -> {
+                                                     cellEditorControls.hide();
+                                                     getExpression().get().ifPresent(e -> addContextEntry(uiRowIndex));
+                                                 }));
+            items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_InsertContextEntryBelow),
+                                                 !isMultiRow,
+                                                 () -> {
+                                                     cellEditorControls.hide();
+                                                     getExpression().get().ifPresent(e -> addContextEntry(uiRowIndex + 1));
+                                                 }));
+            items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ContextEditor_DeleteContextEntry),
+                                                 !isMultiRow && model.getRowCount() > 2 && uiRowIndex < model.getRowCount() - 1,
+                                                 () -> {
+                                                     cellEditorControls.hide();
+                                                     deleteContextEntry(uiRowIndex);
+                                                 }));
+        }
 
         //If not ExpressionEditor column don't add extra items
         if (ContextUIModelMapperHelper.getSection(uiColumnIndex) != ContextUIModelMapperHelper.ContextSection.EXPRESSION) {
@@ -226,7 +274,9 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
             return items;
         }
 
-        items.add(new ListSelectorDividerItem());
+        if (items.size() > 0) {
+            items.add(new ListSelectorDividerItem());
+        }
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.ExpressionEditor_Clear),
                                              !isMultiSelect,
                                              () -> {
@@ -244,7 +294,7 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
     }
 
     void addContextEntry(final int index) {
-        expression.ifPresent(c -> {
+        getExpression().get().ifPresent(c -> {
             final ContextEntry ce = new ContextEntry();
             final InformationItem informationItem = new InformationItem();
             informationItem.setName(new Name());
@@ -254,10 +304,10 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
                                                                                         new AddContextEntryCommand(c,
                                                                                                                    ce,
                                                                                                                    model,
-                                                                                                                   new DMNGridRow(),
+                                                                                                                   new ExpressionEditorGridRow(),
                                                                                                                    index,
                                                                                                                    uiModelMapper,
-                                                                                                                   this::resize));
+                                                                                                                   () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
 
             if (!CommandUtils.isError(result)) {
                 selectCell(index, ContextUIModelMapperHelper.NAME_COLUMN_INDEX, false, false);
@@ -267,12 +317,12 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
     }
 
     void deleteContextEntry(final int index) {
-        expression.ifPresent(c -> {
+        getExpression().get().ifPresent(c -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new DeleteContextEntryCommand(c,
                                                                         model,
                                                                         index,
-                                                                        this::resize));
+                                                                        () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
         });
     }
 
@@ -280,12 +330,55 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
         final GridCellTuple gc = new GridCellTuple(uiRowIndex,
                                                    ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX,
                                                    this);
-        final HasExpression hasExpression = expression.get().getContextEntry().get(uiRowIndex);
-        sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
-                                      new ClearExpressionTypeCommand(gc,
-                                                                     hasExpression,
-                                                                     uiModelMapper,
-                                                                     () -> resizeBasedOnCellExpressionEditor(uiRowIndex,
-                                                                                                             ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX)));
+        getExpression().get().ifPresent(context -> {
+            final HasExpression hasExpression = context.getContextEntry().get(uiRowIndex);
+            sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                          new ClearExpressionTypeCommand(gc,
+                                                                         hasExpression,
+                                                                         uiModelMapper,
+                                                                         () -> {
+                                                                             resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                             selectExpressionEditorFirstCell(uiRowIndex, ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX);
+                                                                         },
+                                                                         () -> {
+                                                                             resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                             selectExpressionEditorFirstCell(uiRowIndex, ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX);
+                                                                         }));
+        });
+    }
+
+    @Override
+    public void doAfterSelectionChange(final int uiRowIndex,
+                                       final int uiColumnIndex) {
+        if (hasAnyHeaderCellSelected() || hasMultipleRowsSelected()) {
+            super.doAfterSelectionChange(uiRowIndex, uiColumnIndex);
+            return;
+        }
+
+        if (uiRowIndex < model.getRowCount() - 1) {
+            if (getExpression().get().isPresent()) {
+                final Context context = getExpression().get().get();
+                fireDomainObjectSelectionEvent(context.getContextEntry().get(uiRowIndex).getVariable());
+                return;
+            }
+        }
+        super.doAfterSelectionChange(uiRowIndex, uiColumnIndex);
+    }
+
+    private boolean hasMultipleRowsSelected() {
+        return getModel().getSelectedCells().stream().map(GridData.SelectedCell::getRowIndex).distinct().count() > 1;
+    }
+
+    @Override
+    public void doAfterHeaderSelectionChange(final int uiHeaderRowIndex,
+                                             final int uiHeaderColumnIndex) {
+        if (uiHeaderColumnIndex == ContextUIModelMapperHelper.NAME_COLUMN_INDEX || uiHeaderColumnIndex == ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX) {
+            final DMNModelInstrumentedBase base = hasExpression.asDMNModelInstrumentedBase();
+            if (base instanceof DomainObject) {
+                fireDomainObjectSelectionEvent((DomainObject) base);
+                return;
+            }
+        }
+        super.doAfterHeaderSelectionChange(uiHeaderRowIndex, uiHeaderColumnIndex);
     }
 }
