@@ -25,6 +25,7 @@ import com.ait.lienzo.shared.core.types.EventPropagationMode;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
 import org.kie.workbench.common.dmn.api.definition.v1_1.List;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Relation;
@@ -33,39 +34,48 @@ import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.A
 import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.AddRelationRowCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.DeleteRelationColumnCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.DeleteRelationRowCommand;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.util.SelectionUtils;
+import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGridRenderer;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
-import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.LiteralExpressionGridRow;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
+import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.GridRow;
+import org.uberfire.ext.wires.core.grids.client.util.CellContextUtilities;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
+import static org.kie.workbench.common.dmn.client.editors.expressions.util.RendererUtils.getExpressionTextLineHeight;
+
 public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData, RelationUIModelMapper> implements HasListSelectorControl {
 
     private final TextAreaSingletonDOMElementFactory factory = getBodyTextAreaFactory();
-    private final TextBoxSingletonDOMElementFactory headerFactory = getHeaderTextBoxFactory();
+
+    private final NameAndDataTypePopoverView.Presenter headerEditor;
 
     public RelationGrid(final GridCellTuple parent,
                         final Optional<String> nodeUUID,
                         final HasExpression hasExpression,
-                        final Optional<Relation> expression,
                         final Optional<HasName> hasName,
                         final DMNGridPanel gridPanel,
                         final DMNGridLayer gridLayer,
@@ -73,30 +83,37 @@ public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData,
                         final DefinitionUtils definitionUtils,
                         final SessionManager sessionManager,
                         final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                        final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                        final DefaultCanvasCommandFactory canvasCommandFactory,
                         final Event<ExpressionEditorChanged> editorSelectedEvent,
+                        final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                        final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                         final CellEditorControlsView.Presenter cellEditorControls,
                         final ListSelectorView.Presenter listSelector,
                         final TranslationService translationService,
-                        final int nesting) {
+                        final boolean isOnlyVisualChangeAllowed,
+                        final int nesting,
+                        final NameAndDataTypePopoverView.Presenter headerEditor) {
         super(parent,
               nodeUUID,
               hasExpression,
-              expression,
               hasName,
               gridPanel,
               gridLayer,
               gridData,
-              new RelationGridRenderer(),
+              new BaseExpressionGridRenderer(gridData),
               definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               cellEditorControls,
               listSelector,
               translationService,
+              isOnlyVisualChangeAllowed,
               nesting);
+        this.headerEditor = headerEditor;
 
         setEventPropagationMode(EventPropagationMode.NO_ANCESTORS);
 
@@ -112,38 +129,56 @@ public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData,
     @Override
     public RelationUIModelMapper makeUiModelMapper() {
         return new RelationUIModelMapper(this::getModel,
-                                         () -> expression,
+                                         getExpression(),
                                          listSelector);
     }
 
     @Override
     public void initialiseUiColumns() {
-        expression.ifPresent(e -> {
-            model.appendColumn(new RowNumberColumn());
-            e.getColumn().forEach(ii -> {
-                final GridColumn relationColumn = makeRelationColumn(ii);
+        int uiColumnIndex = 0;
+        final RowNumberColumn rowNumberColumn = new RowNumberColumn();
+        rowNumberColumn.setWidth(getAndSetInitialWidth(uiColumnIndex++, rowNumberColumn.getWidth()));
+
+        if (getExpression().get().isPresent()) {
+            model.appendColumn(rowNumberColumn);
+            final Relation e = getExpression().get().get();
+            for (int index = 0; index < e.getColumn().size(); index++) {
+                final GridColumn relationColumn = makeRelationColumn(uiColumnIndex++, e.getColumn().get(index));
                 model.appendColumn(relationColumn);
-            });
-        });
+            }
+        }
 
         getRenderer().setColumnRenderConstraint((isSelectionLayer, gridColumn) -> true);
     }
 
-    private RelationColumn makeRelationColumn(final InformationItem informationItem) {
-        final RelationColumn relationColumn = new RelationColumn(new RelationColumnHeaderMetaData(() -> informationItem.getName().getValue(),
-                                                                                                  (s) -> informationItem.getName().setValue(s),
-                                                                                                  headerFactory),
+    private RelationColumn makeRelationColumn(final int index,
+                                              final InformationItem informationItem) {
+        final RelationColumn relationColumn = new RelationColumn(new RelationColumnHeaderMetaData(informationItem,
+                                                                                                  clearDisplayNameConsumer(false),
+                                                                                                  setDisplayNameConsumer(false),
+                                                                                                  setTypeRefConsumer(),
+                                                                                                  cellEditorControls,
+                                                                                                  headerEditor,
+                                                                                                  Optional.of(translationService.getTranslation(DMNEditorConstants.RelationEditor_EditRelation)),
+                                                                                                  listSelector,
+                                                                                                  this::getHeaderItems,
+                                                                                                  this::onItemSelected),
                                                                  factory,
+                                                                 getAndSetInitialWidth(index, DMNGridColumn.DEFAULT_WIDTH),
                                                                  this);
         return relationColumn;
     }
 
+    private GridRow makeRelationRow() {
+        return new LiteralExpressionGridRow(getExpressionTextLineHeight(getRenderer().getTheme()));
+    }
+
     @Override
     public void initialiseUiModel() {
-        expression.ifPresent(e -> {
+        getExpression().get().ifPresent(e -> {
             e.getRow().forEach(r -> {
                 int columnIndex = 0;
-                model.appendRow(new DMNGridRow());
+                model.appendRow(makeRelationRow());
                 uiModelMapper.fromDMNModel(model.getRowCount() - 1,
                                            columnIndex++);
                 for (int ii = 0; ii < e.getColumn().size(); ii++) {
@@ -154,9 +189,14 @@ public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData,
         });
     }
 
-    @Override
-    protected boolean isHeaderHidden() {
-        return false;
+    @SuppressWarnings("unused")
+    java.util.List<ListSelectorItem> getHeaderItems(final int uiHeaderRowIndex,
+                                                    final int uiHeaderColumnIndex) {
+        final java.util.List<ListSelectorItem> items = new ArrayList<>();
+
+        addColumnItems(items, uiHeaderColumnIndex);
+
+        return items;
     }
 
     @Override
@@ -164,49 +204,57 @@ public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData,
     public java.util.List<ListSelectorItem> getItems(final int uiRowIndex,
                                                      final int uiColumnIndex) {
         final java.util.List<ListSelectorItem> items = new ArrayList<>();
-        final boolean isMultiRow = SelectionUtils.isMultiRow(model);
-        final boolean isMultiColumn = SelectionUtils.isMultiColumn(model);
 
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_InsertColumnBefore),
-                                             !isMultiColumn && uiColumnIndex > 0,
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addColumn(uiColumnIndex));
-                                             }));
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_InsertColumnAfter),
-                                             !isMultiColumn && uiColumnIndex > 0,
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addColumn(uiColumnIndex + 1));
-                                             }));
-        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_DeleteColumn),
-                                             !isMultiColumn && model.getColumnCount() - RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT > 1 && uiColumnIndex > 0,
-                                             () -> {
-                                                 cellEditorControls.hide();
-                                                 expression.ifPresent(e -> deleteColumn(uiColumnIndex));
-                                             }));
-        items.add(new ListSelectorDividerItem());
+        addColumnItems(items, uiColumnIndex);
+
+        final boolean isMultiRow = SelectionUtils.isMultiRow(model);
+        items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.RelationEditor_HeaderRows)));
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_InsertRowAbove),
                                              !isMultiRow,
                                              () -> {
                                                  cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addRow(uiRowIndex));
+                                                 getExpression().get().ifPresent(e -> addRow(uiRowIndex));
                                              }));
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_InsertRowBelow),
                                              !isMultiRow,
                                              () -> {
                                                  cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addRow(uiRowIndex + 1));
+                                                 getExpression().get().ifPresent(e -> addRow(uiRowIndex + 1));
                                              }));
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_DeleteRow),
                                              !isMultiRow && model.getRowCount() > 1,
                                              () -> {
                                                  cellEditorControls.hide();
-                                                 expression.ifPresent(e -> deleteRow(uiRowIndex));
+                                                 getExpression().get().ifPresent(e -> deleteRow(uiRowIndex));
                                              }));
         return items;
     }
 
+    private void addColumnItems(final java.util.List<ListSelectorItem> items,
+                                final int uiColumnIndex) {
+        final boolean isMultiColumn = SelectionUtils.isMultiColumn(model);
+
+        items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.RelationEditor_HeaderColumns)));
+        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_InsertColumnLeft),
+                                             !isMultiColumn && uiColumnIndex > 0,
+                                             () -> {
+                                                 cellEditorControls.hide();
+                                                 getExpression().get().ifPresent(e -> addColumn(uiColumnIndex));
+                                             }));
+        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_InsertColumnRight),
+                                             !isMultiColumn && uiColumnIndex > 0,
+                                             () -> {
+                                                 cellEditorControls.hide();
+                                                 getExpression().get().ifPresent(e -> addColumn(uiColumnIndex + 1));
+                                             }));
+        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.RelationEditor_DeleteColumn),
+                                             !isMultiColumn && model.getColumnCount() - RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT > 1 && uiColumnIndex > 0,
+                                             () -> {
+                                                 cellEditorControls.hide();
+                                                 getExpression().get().ifPresent(e -> deleteColumn(uiColumnIndex));
+                                             }));
+    }
+
     @Override
     public void onItemSelected(final ListSelectorItem item) {
         final ListSelectorTextItem li = (ListSelectorTextItem) item;
@@ -214,57 +262,100 @@ public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData,
     }
 
     void addColumn(final int index) {
-        expression.ifPresent(relation -> {
+        getExpression().get().ifPresent(relation -> {
             final InformationItem informationItem = new InformationItem();
-            final RelationColumn relationColumn = makeRelationColumn(informationItem);
             informationItem.setName(new Name());
 
             final CommandResult<CanvasViolation> result = sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                                                                         new AddRelationColumnCommand(relation,
                                                                                                                      informationItem,
                                                                                                                      model,
-                                                                                                                     relationColumn,
+                                                                                                                     () -> makeRelationColumn(index, informationItem),
                                                                                                                      index,
                                                                                                                      uiModelMapper,
-                                                                                                                     this::resize));
+                                                                                                                     () -> resize(BaseExpressionGrid.RESIZE_EXISTING),
+                                                                                                                     () -> resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM)));
 
             if (!CommandUtils.isError(result)) {
-                relationColumn.startEditingHeaderCell(0);
+                selectHeaderCell(0, index, false, false);
+                CellContextUtilities.editSelectedCell(this);
             }
         });
     }
 
     void deleteColumn(final int index) {
-        expression.ifPresent(relation -> {
+        getExpression().get().ifPresent(relation -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new DeleteRelationColumnCommand(relation,
                                                                           model,
                                                                           index,
                                                                           uiModelMapper,
-                                                                          this::resize));
+                                                                          () -> resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM),
+                                                                          () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
         });
     }
 
     void addRow(final int index) {
-        expression.ifPresent(relation -> {
+        getExpression().get().ifPresent(relation -> {
+            final GridRow relationRow = makeRelationRow();
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new AddRelationRowCommand(relation,
                                                                     new List(),
                                                                     model,
-                                                                    new DMNGridRow(),
+                                                                    relationRow,
                                                                     index,
                                                                     uiModelMapper,
-                                                                    this::resize));
+                                                                    () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
         });
     }
 
     void deleteRow(final int index) {
-        expression.ifPresent(relation -> {
+        getExpression().get().ifPresent(relation -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new DeleteRelationRowCommand(relation,
                                                                        model,
                                                                        index,
-                                                                       this::resize));
+                                                                       () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
         });
     }
+
+    @Override
+    public void doAfterSelectionChange(final int uiRowIndex,
+                                       final int uiColumnIndex) {
+        if (hasAnyHeaderCellSelected() || hasMultipleCellsSelected()) {
+            super.doAfterSelectionChange(uiRowIndex, uiColumnIndex);
+            return;
+        }
+
+        if (getExpression().get().isPresent()) {
+            final Relation relation = getExpression().get().get();
+            final RelationUIModelMapperHelper.RelationSection section = RelationUIModelMapperHelper.getSection(relation, uiColumnIndex);
+            if (section == RelationUIModelMapperHelper.RelationSection.INFORMATION_ITEM) {
+                final int iiIndex = RelationUIModelMapperHelper.getInformationItemIndex(relation, uiColumnIndex);
+                final Expression relationExpression = relation.getRow().get(uiRowIndex).getExpression().get(iiIndex);
+                if (relationExpression instanceof DomainObject) {
+                    final DomainObject domainObject = (DomainObject) relationExpression;
+                    fireDomainObjectSelectionEvent(domainObject);
+                    return;
+                }
+            }
+        }
+        super.doAfterSelectionChange(uiRowIndex, uiColumnIndex);
+    }
+
+    @Override
+    public void doAfterHeaderSelectionChange(final int uiHeaderRowIndex,
+                                             final int uiHeaderColumnIndex) {
+        if (getExpression().get().isPresent()) {
+            final Relation relation = getExpression().get().get();
+            final RelationUIModelMapperHelper.RelationSection section = RelationUIModelMapperHelper.getSection(relation, uiHeaderColumnIndex);
+            if (section == RelationUIModelMapperHelper.RelationSection.INFORMATION_ITEM) {
+                final int iiIndex = RelationUIModelMapperHelper.getInformationItemIndex(relation, uiHeaderColumnIndex);
+                final InformationItem domainObject = relation.getColumn().get(iiIndex);
+                fireDomainObjectSelectionEvent(domainObject);
+                return;
+            }
+        }
+        super.doAfterHeaderSelectionChange(uiHeaderRowIndex, uiHeaderColumnIndex);
+    }
 }
