@@ -17,13 +17,20 @@
 package org.kie.workbench.common.forms.dynamic.client.rendering.renderers.selectors.listBox;
 
 import javax.enterprise.context.Dependent;
+import javax.inject.Inject;
 
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.EnumSelectorOption;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.EnumListBoxFieldDefinition;
 
 @Dependent
 public class EnumListBoxFieldRenderer
-        extends AbstractListBoxFieldRenderer<EnumListBoxFieldDefinition, EnumSelectorOption,Enum> {
+        extends AbstractListBoxFieldRenderer<EnumListBoxFieldDefinition, EnumSelectorOption, Enum> {
+
+    @Inject
+    public EnumListBoxFieldRenderer(TranslationService translationService) {
+        super(translationService);
+    }
 
     @Override
     public Class<EnumListBoxFieldDefinition> getSupportedFieldDefinition() {
