@@ -54,6 +54,7 @@ import org.kie.workbench.common.workbench.client.events.LayoutEditorFocusEvent;
 import org.mockito.Mock;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.client.promise.Promises;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.DeletePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.DeletePopUpView;
@@ -63,12 +64,14 @@ import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
 import org.uberfire.ext.layout.editor.client.api.LayoutDragComponentPalette;
 import org.uberfire.ext.layout.editor.client.api.LayoutEditor;
+import org.uberfire.ext.layout.editor.client.widgets.LayoutEditorPropertiesPresenter;
 import org.uberfire.ext.plugin.client.perspective.editor.layout.editor.HTMLLayoutDragComponent;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
@@ -172,6 +175,10 @@ public class FormEditorPresenterAbstractTest {
 
     @Mock
     protected ErrorMessageDisplayer errorMessageDisplayer;
+    @Mock
+    private FormFieldPropertiesEditorDock formFieldPropertiesEditorDock;
+    @Mock
+    LayoutEditorPropertiesPresenter layoutEditorPropertiesPresenter;
 
     @Mock
     protected MenuItem downloadMenuItem;
@@ -184,6 +191,8 @@ public class FormEditorPresenterAbstractTest {
 
     protected CallerMock<FormEditorService> editorServiceCallerMock;
 
+    protected Promises promises;
+
     protected FormEditorPresenter presenter;
     protected FormModelerContent content;
 
@@ -195,6 +204,7 @@ public class FormEditorPresenterAbstractTest {
 
     @Before
     public void setUp() throws Exception {
+        promises = new SyncPromises();
         fieldManager = new TestFieldManager();
 
         model = new PortableJavaModel("com.test.Employee");
@@ -274,7 +284,9 @@ public class FormEditorPresenterAbstractTest {
                                             translationService,
                                             editorFieldLayoutComponents,
                                             showAssetUsagesDisplayer,
-                                            errorMessageDisplayer) {
+                                            errorMessageDisplayer,
+                                            formFieldPropertiesEditorDock,
+                                            layoutEditorPropertiesPresenter) {
             {
                 kieView = mock(KieEditorWrapperView.class);
                 versionRecordManager = FormEditorPresenterAbstractTest.this.versionRecordManager;
@@ -294,6 +306,7 @@ public class FormEditorPresenterAbstractTest {
                 alertsButtonMenuItemBuilder = FormEditorPresenterAbstractTest.this.alertsButtonMenuItemBuilder;
                 formEditorContext = mock(FormEditorContext.class);
                 copyPopUpPresenter = FormEditorPresenterAbstractTest.this.copyPopUpPresenter;
+                promises = FormEditorPresenterAbstractTest.this.promises;
             }
 
             @Override
