@@ -15,20 +15,18 @@
  */
 package org.kie.workbench.common.screens.impl;
 
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
-import java.util.stream.Stream;
-
 import javax.enterprise.event.Event;
 
-import org.ext.uberfire.social.activities.model.SocialUser;
-import org.ext.uberfire.social.activities.service.SocialUserRepositoryAPI;
 import org.guvnor.common.services.project.backend.server.utils.PathUtil;
-import org.guvnor.common.services.project.events.NewProjectEvent;
 import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.POM;
@@ -36,20 +34,25 @@ import org.guvnor.common.services.project.model.Package;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.DeploymentMode;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
+import org.guvnor.structure.backend.repositories.ConfiguredRepositories;
+import org.guvnor.structure.contributors.Contributor;
+import org.guvnor.structure.contributors.ContributorType;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
-import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
+import org.guvnor.structure.organizationalunit.config.SpaceConfigStorage;
+import org.guvnor.structure.organizationalunit.config.SpaceConfigStorageRegistry;
 import org.guvnor.structure.repositories.Branch;
+import org.guvnor.structure.repositories.NewBranchEvent;
 import org.guvnor.structure.repositories.Repository;
-import org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations;
+import org.guvnor.structure.repositories.RepositoryExternalUpdateEvent;
 import org.guvnor.structure.repositories.RepositoryService;
-import org.guvnor.structure.repositories.impl.git.GitRepository;
 import org.guvnor.structure.security.RepositoryAction;
+import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.screens.examples.model.ExampleProject;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
+import org.kie.workbench.common.screens.examples.model.ImportProject;
 import org.kie.workbench.common.screens.examples.service.ExamplesService;
 import org.kie.workbench.common.screens.explorer.backend.server.ExplorerServiceHelper;
 import org.kie.workbench.common.screens.library.api.AssetInfo;
@@ -62,6 +65,7 @@ import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalP
 import org.kie.workbench.common.screens.library.api.preferences.LibraryOrganizationalUnitPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryProjectPreferences;
+import org.kie.workbench.common.services.refactoring.backend.server.query.standard.FindAllLibraryAssetsQuery;
 import org.kie.workbench.common.services.refactoring.model.index.terms.valueterms.ValueIndexTerm;
 import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRequest;
 import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRow;
@@ -72,32 +76,24 @@ import org.mockito.Captor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.Path;
-import org.uberfire.backend.vfs.PathFactory;
+import org.uberfire.ext.security.management.api.service.UserManagerService;
 import org.uberfire.io.IOService;
+import org.uberfire.java.nio.file.FileSystem;
 import org.uberfire.java.nio.file.NoSuchFileException;
 import org.uberfire.java.nio.file.spi.FileSystemProvider;
-import org.uberfire.java.nio.fs.jgit.JGitFileSystem;
-import org.uberfire.java.nio.fs.jgit.JGitPathImpl;
+import org.uberfire.mocks.EventSourceMock;
+import org.uberfire.mocks.SessionInfoMock;
 import org.uberfire.paging.PageResponse;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.spaces.Space;
 
-import static java.util.Collections.emptyList;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.same;
-import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.times;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
+import static org.mockito.Mockito.*;
 
 @RunWith(MockitoJUnitRunner.class)
 public class LibraryServiceImplTest {
@@ -108,6 +104,9 @@ public class LibraryServiceImplTest {
     @Mock
     private AuthorizationManager authorizationManager;
 
+    @Mock
+    private SessionInfo sessionInfo;
+
     @Mock
     private WorkspaceProjectService projectService;
 
@@ -133,7 +132,7 @@ public class LibraryServiceImplTest {
     private IOService ioService;
 
     @Mock
-    private SocialUserRepositoryAPI socialUserRepositoryAPI;
+    private UserManagerService userManagerService;
 
     @Mock
     private IndexStatusOracle indexOracle;
@@ -141,14 +140,23 @@ public class LibraryServiceImplTest {
     @Mock
     private RepositoryService repositoryService;
 
-    @Mock
-    private Event<NewProjectEvent> newProjectEvent;
-
     @Mock
     private PathUtil pathUtil;
 
     private final PathUtil realPathUtil = new PathUtil();
 
+    @Mock
+    private ConfiguredRepositories configuredRepositories;
+
+    @Mock
+    private EventSourceMock<RepositoryExternalUpdateEvent> repositoryExternalUpdateEvent;
+
+    @Mock
+    private SpaceConfigStorageRegistry spaceConfigStorageRegistry;
+
+    @Mock
+    private Event<NewBranchEvent> newBranchEvent;
+
     @Mock
     private OrganizationalUnit ou1;
 
@@ -171,11 +179,6 @@ public class LibraryServiceImplTest {
     private List<OrganizationalUnit> ous;
     private Set<Module> modulesMock;
 
-    private Branch makeBranch(final String branchName) {
-        return new Branch(branchName,
-                          mock(Path.class));
-    }
-
     @Before
     public void setup() {
         ous = Arrays.asList(ou1,
@@ -184,10 +187,16 @@ public class LibraryServiceImplTest {
         when(ou1.getIdentifier()).thenReturn("ou1");
         when(ou2.getIdentifier()).thenReturn("ou2");
         when(repo1.getAlias()).thenReturn("repo_created_by_user");
-        when(repo1.getBranches()).thenReturn(Arrays.asList(makeBranch("repo1-branch1"),
-                                                           makeBranch("repo1-branch2")));
+        final List<Branch> repo1Branches = Arrays.asList(makeBranch("repo1-branch1",
+                                                                    repo1.getAlias()),
+                                                         makeBranch("repo1-branch2",
+                                                                    repo1.getAlias()));
+        when(repo1.getBranches()).thenReturn(repo1Branches);
+        when(repo1.getBranch(anyString())).then(inv -> repo1Branches.stream().filter(b -> b.getName().equals(inv.getArgumentAt(0, String.class))).findFirst());
         when(repo2Default.getAlias()).thenReturn("ou2-repo-alias");
-        when(repo2Default.getBranches()).thenReturn(Collections.singletonList(makeBranch("repo2-branch1")));
+        final List<Branch> repo2Branches = Collections.singletonList(makeBranch("repo2-branch1",
+                                                                                repo2Default.getAlias()));
+        when(repo2Default.getBranches()).thenReturn(repo2Branches);
         when(ou2.getRepositories()).thenReturn(Arrays.asList(repo1,
                                                              repo2Default));
 
@@ -201,29 +210,38 @@ public class LibraryServiceImplTest {
         when(preferences.getOrganizationalUnitPreferences()).thenReturn(spy(new LibraryOrganizationalUnitPreferences()));
         when(preferences.getProjectPreferences()).thenReturn(spy(new LibraryProjectPreferences()));
 
+        sessionInfo = new SessionInfoMock();
+
         libraryService = spy(new LibraryServiceImpl(ouService,
                                                     refactoringQueryService,
                                                     preferences,
                                                     authorizationManager,
-                                                    mock(SessionInfo.class),
+                                                    sessionInfo,
                                                     explorerServiceHelper,
                                                     projectService,
                                                     moduleService,
                                                     examplesService,
-                                                    repositoryService,
                                                     ioService,
                                                     internalPreferences,
-                                                    socialUserRepositoryAPI,
+                                                    userManagerService,
                                                     indexOracle,
-                                                    newProjectEvent,
-                                                    pathUtil
+                                                    repositoryService,
+                                                    pathUtil,
+                                                    newBranchEvent,
+                                                    configuredRepositories,
+                                                    repositoryExternalUpdateEvent,
+                                                    spaceConfigStorageRegistry
         ));
     }
 
     @Test
     public void queryingUnindexedProjectGivesUnindexedResult() throws Exception {
-        Branch branch = new Branch("fake-branch", mockPath("default:///a/b/c"));
-        final WorkspaceProject project = new WorkspaceProject(ou1, repo1, branch, mock(Module.class));
+        Branch branch = new Branch("fake-branch",
+                                   mockPath("default:///a/b/c"));
+        final WorkspaceProject project = new WorkspaceProject(ou1,
+                                                              repo1,
+                                                              branch,
+                                                              mock(Module.class));
         when(indexOracle.isIndexed(project)).thenReturn(false);
         when(ioService.exists(any())).thenReturn(true);
 
@@ -234,7 +252,8 @@ public class LibraryServiceImplTest {
                                                                 Collections.emptyList());
 
         AssetQueryResult result = libraryService.getProjectAssets(query);
-        assertEquals(ResultType.Unindexed, result.getResultType());
+        assertEquals(ResultType.Unindexed,
+                     result.getResultType());
         assertFalse(result.getAssetInfos().isPresent());
     }
 
@@ -279,8 +298,10 @@ public class LibraryServiceImplTest {
 
         final LibraryInfo libraryInfo = libraryService.getLibraryInfo(ou1);
 
-        assertEquals(1, libraryInfo.getProjects().size());
-        assertSame(project2, libraryInfo.getProjects().iterator().next());
+        assertEquals(1,
+                     libraryInfo.getProjects().size());
+        assertSame(project2,
+                   libraryInfo.getProjects().iterator().next());
     }
 
     @Test
@@ -313,6 +334,75 @@ public class LibraryServiceImplTest {
                      pom.getDescription());
     }
 
+    @Test
+    public void createProjectTest() {
+        final List<Contributor> spaceContributors = new ArrayList<>();
+        spaceContributors.add(new Contributor("user1", ContributorType.OWNER));
+        spaceContributors.add(new Contributor("user2", ContributorType.ADMIN));
+        spaceContributors.add(new Contributor("admin", ContributorType.CONTRIBUTOR));
+
+        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
+        doReturn("ou").when(organizationalUnit).getName();
+        doReturn("org.ou").when(organizationalUnit).getDefaultGroupId();
+        doReturn(spaceContributors).when(organizationalUnit).getContributors();
+        doReturn(organizationalUnit).when(ouService).getOrganizationalUnit("ou");
+
+        final POM pom = mock(POM.class);
+
+        libraryService.createProject(organizationalUnit,
+                                     pom,
+                                     DeploymentMode.VALIDATED);
+
+        verify(ouService, never()).updateOrganizationalUnit(anyString(), anyString(), anyList());
+
+        final List<Contributor> projectContributors = new ArrayList<>();
+        projectContributors.add(new Contributor("user1", ContributorType.OWNER));
+        projectContributors.add(new Contributor("user2", ContributorType.ADMIN));
+        projectContributors.add(new Contributor("admin", ContributorType.OWNER));
+        verify(projectService).newProject(organizationalUnit,
+                                          pom,
+                                          DeploymentMode.VALIDATED,
+                                          projectContributors);
+    }
+
+    @Test
+    public void createProjectWithUserThatIsNotASpaceContributorTest() {
+        final List<Contributor> spaceContributors = new ArrayList<>();
+        spaceContributors.add(new Contributor("user1", ContributorType.OWNER));
+        spaceContributors.add(new Contributor("user2", ContributorType.ADMIN));
+        spaceContributors.add(new Contributor("user3", ContributorType.CONTRIBUTOR));
+
+        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
+        doReturn("ou").when(organizationalUnit).getName();
+        doReturn("org.ou").when(organizationalUnit).getDefaultGroupId();
+        doReturn(spaceContributors).when(organizationalUnit).getContributors();
+        doReturn(organizationalUnit).when(ouService).getOrganizationalUnit("ou");
+
+        final POM pom = mock(POM.class);
+
+        libraryService.createProject(organizationalUnit,
+                                     pom,
+                                     DeploymentMode.VALIDATED);
+
+
+        final List<Contributor> updatedSpaceContributors = new ArrayList<>();
+        updatedSpaceContributors.add(new Contributor("user1", ContributorType.OWNER));
+        updatedSpaceContributors.add(new Contributor("user2", ContributorType.ADMIN));
+        updatedSpaceContributors.add(new Contributor("user3", ContributorType.CONTRIBUTOR));
+        updatedSpaceContributors.add(new Contributor("admin", ContributorType.CONTRIBUTOR));
+        verify(ouService).updateOrganizationalUnit(anyString(), anyString(), eq(updatedSpaceContributors));
+
+        final List<Contributor> projectContributors = new ArrayList<>();
+        projectContributors.add(new Contributor("user1", ContributorType.OWNER));
+        projectContributors.add(new Contributor("user2", ContributorType.ADMIN));
+        projectContributors.add(new Contributor("user3", ContributorType.CONTRIBUTOR));
+        projectContributors.add(new Contributor("admin", ContributorType.OWNER));
+        verify(projectService).newProject(organizationalUnit,
+                                          pom,
+                                          DeploymentMode.VALIDATED,
+                                          projectContributors);
+    }
+
     @Test
     public void thereIsNotAModuleInTheWorkbenchTest() {
 
@@ -350,7 +440,10 @@ public class LibraryServiceImplTest {
     @Test
     public void emptyFirstPage() throws Exception {
         final Branch branch = mock(Branch.class);
-        final WorkspaceProject project = spy(new WorkspaceProject(ou1, repo1, branch, null));
+        final WorkspaceProject project = spy(new WorkspaceProject(ou1,
+                                                                  repo1,
+                                                                  branch,
+                                                                  null));
         final Path path = mock(Path.class);
 
         when(branch.getPath()).thenReturn(path);
@@ -393,10 +486,10 @@ public class LibraryServiceImplTest {
 
         final Branch branch = mock(Branch.class);
         final Path path = mockPath("file://the_project");
-        final WorkspaceProject project =  spy(new WorkspaceProject(mock(OrganizationalUnit.class),
-                                                               repo1,
-                                                               branch,
-                                                               null));
+        final WorkspaceProject project = spy(new WorkspaceProject(mock(OrganizationalUnit.class),
+                                                                  repo1,
+                                                                  branch,
+                                                                  null));
 
         when(branch.getPath()).thenReturn(path);
 
@@ -471,7 +564,8 @@ public class LibraryServiceImplTest {
 
         final AssetQueryResult result = libraryService.getProjectAssets(query);
 
-        assertEquals(ResultType.Normal, result.getResultType());
+        assertEquals(ResultType.Normal,
+                     result.getResultType());
         assertTrue(result.getAssetInfos().isPresent());
         List<AssetInfo> projectAssets = result.getAssetInfos().get();
         assertTrue(projectAssets.isEmpty());
@@ -554,14 +648,14 @@ public class LibraryServiceImplTest {
         System.setProperty("org.kie.project.examples.repository.url",
                            "importProjectsUrl");
 
-        final Set<ExampleProject> exampleProjects = new HashSet<>();
-        exampleProjects.add(mock(ExampleProject.class));
-        doReturn(exampleProjects).when(examplesService).getProjects(new ExampleRepository("importProjectsUrl"));
+        final Set<ImportProject> importProjects = new HashSet<>();
+        importProjects.add(mock(ImportProject.class));
+        doReturn(importProjects).when(examplesService).getProjects(new ExampleRepository("importProjectsUrl"));
 
-        final Set<ExampleProject> loadedExampleProjects = libraryService.getExampleProjects();
+        final Set<ImportProject> loadedImportProjects = libraryService.getExampleProjects();
 
-        assertEquals(exampleProjects,
-                     loadedExampleProjects);
+        assertEquals(importProjects,
+                     loadedImportProjects);
     }
 
     @Test
@@ -572,148 +666,14 @@ public class LibraryServiceImplTest {
         final ExampleRepository playgroundRepository = new ExampleRepository("playgroundRepositoryUrl");
         doReturn(playgroundRepository).when(examplesService).getPlaygroundRepository();
 
-        final Set<ExampleProject> exampleProjects = new HashSet<>();
-        exampleProjects.add(mock(ExampleProject.class));
-        doReturn(exampleProjects).when(examplesService).getProjects(playgroundRepository);
+        final Set<ImportProject> importProjects = new HashSet<>();
+        importProjects.add(mock(ImportProject.class));
+        doReturn(importProjects).when(examplesService).getProjects(playgroundRepository);
 
-        final Set<ExampleProject> loadedExampleProjects = libraryService.getExampleProjects();
+        final Set<ImportProject> loadedImportProjects = libraryService.getExampleProjects();
 
-        assertEquals(exampleProjects,
-                     loadedExampleProjects);
-    }
-
-    @Test
-    public void importProjectWithCredentialsTest() {
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
-        final Repository repo = mock(Repository.class);
-        final WorkspaceProject project = mock(WorkspaceProject.class);
-
-        final String repositoryURL = "file:///some/path/to/fake-repo.git";
-        final String username = "fakeUser";
-        final String password = "fakePassword";
-
-        final ArgumentCaptor<RepositoryEnvironmentConfigurations> configCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
-
-        when(repositoryService.createRepository(any(), any(), any(), configCaptor.capture())).thenReturn(repo);
-        when(projectService.resolveProject(any(Repository.class))).thenReturn(project);
-
-        final WorkspaceProject observedProject = libraryService.importProject(organizationalUnit, repositoryURL, username, password);
-
-        verify(repositoryService).createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), eq("fake-repo"), any());
-        RepositoryEnvironmentConfigurations observedConfig = configCaptor.getValue();
-        assertEquals(username, observedConfig.getUserName());
-        assertEquals(password, observedConfig.getPassword());
-        assertEquals(repositoryURL, observedConfig.getOrigin());
-
-        verify(projectService).resolveProject(same(repo));
-
-        assertSame(project, observedProject);
-    }
-
-    @Test
-    public void importProjectWithoutCredentialsTest() {
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
-        final Repository repo = mock(Repository.class);
-        final WorkspaceProject project = mock(WorkspaceProject.class);
-
-        final String repositoryURL = "file:///some/path/to/fake-repo.git";
-        final String username = null;
-        final String password = null;
-
-        final ArgumentCaptor<RepositoryEnvironmentConfigurations> configCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
-
-        when(repositoryService.createRepository(any(), any(), any(), configCaptor.capture())).thenReturn(repo);
-        when(projectService.resolveProject(any(Repository.class))).thenReturn(project);
-
-        final WorkspaceProject observedProject = libraryService.importProject(organizationalUnit, repositoryURL, username, password);
-
-        verify(repositoryService).createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), eq("fake-repo"), any());
-        RepositoryEnvironmentConfigurations observedConfig = configCaptor.getValue();
-        assertEquals(username, observedConfig.getUserName());
-        assertEquals(password, observedConfig.getPassword());
-        assertEquals(repositoryURL, observedConfig.getOrigin());
-
-        verify(projectService).resolveProject(same(repo));
-
-        assertSame(project, observedProject);
-    }
-
-    @Test
-    public void importDefaultProjectTest() {
-        final OrganizationalUnit organizationalUnit = new OrganizationalUnitImpl("myteam", "admin", "org.whatever");
-        organizationalUnit.getRepositories();
-
-        final Path exampleRoot = mock(Path.class);
-        final org.uberfire.java.nio.file.Path exampleRootNioPath = mock(org.uberfire.java.nio.file.Path.class);
-        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
-        final ExampleProject exampleProject = new ExampleProject(exampleRoot, "example", "description", emptyList());
-
-        String repoURL = "file:///some/repo/url";
-        when(pathUtil.getNiogitRepoPath(any())).thenReturn(repoURL);
-
-        final Repository repository = new GitRepository("example", new Space("myteam"));
-        final WorkspaceProject project = new WorkspaceProject(organizationalUnit,
-                                                              repository,
-                                                              new Branch("master", mock(Path.class)),
-                                                              new Module());
-        when(projectService.resolveProject(repository)).thenReturn(project);
-        when(repositoryService.createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), any())).thenReturn(repository);
-
-        final WorkspaceProject importedProject = libraryService.importProject(organizationalUnit,
-                                                                              exampleProject);
-
-        assertSame(project, importedProject);
-        final ArgumentCaptor<RepositoryEnvironmentConfigurations> configsCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
-        verify(repositoryService).createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), configsCaptor.capture());
-        final RepositoryEnvironmentConfigurations configs = configsCaptor.getValue();
-        assertEquals(repoURL, configs.getOrigin());
-        assertNull(configs.getSubdirectory());
-        verify(projectService).resolveProject(repository);
-    }
-
-    @Test
-    public void importProjectInSubdirectory() {
-        final OrganizationalUnit organizationalUnit = new OrganizationalUnitImpl("myteam", "admin", "org.whatever");
-        organizationalUnit.getRepositories();
-
-
-        final String exampleURI = "default://master@system/repo/example";
-        final Path exampleRoot = PathFactory.newPath("example", exampleURI);
-        final JGitFileSystem fs = mock(JGitFileSystem.class);
-        final FileSystemProvider provider = mock(FileSystemProvider.class);
-        when(fs.provider()).thenReturn(provider);
-        final org.uberfire.java.nio.file.Path exampleRootNioPath = JGitPathImpl.create(fs, "/example", "master@system/repo", true);
-        final org.uberfire.java.nio.file.Path repoRoot = exampleRootNioPath.getParent();
-        when(fs.getRootDirectories()).thenReturn(() -> Stream.of(repoRoot).iterator());
-        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
-        when(pathUtil.stripProtocolAndBranch(any())).then(inv -> realPathUtil.stripProtocolAndBranch(inv.getArgumentAt(0, String.class)));
-        when(pathUtil.stripRepoNameAndSpace(any())).then(inv -> realPathUtil.stripRepoNameAndSpace(inv.getArgumentAt(0, String.class)));
-        when(pathUtil.convert(any(org.uberfire.java.nio.file.Path.class))).then(inv -> realPathUtil.convert(inv.getArgumentAt(0, org.uberfire.java.nio.file.Path.class)));
-        when(pathUtil.extractBranch(any())).then(inv -> realPathUtil.extractBranch(inv.getArgumentAt(0, String.class)));
-
-        final ExampleProject exampleProject = new ExampleProject(exampleRoot, "example", "description", emptyList());
-
-        String repoURL = "file:///some/repo/url";
-        when(pathUtil.getNiogitRepoPath(any())).thenReturn(repoURL);
-
-        final Repository repository = new GitRepository("example", new Space("myteam"));
-        final WorkspaceProject project = new WorkspaceProject(organizationalUnit,
-                                                              repository,
-                                                              new Branch("master", mock(Path.class)),
-                                                              new Module());
-        when(projectService.resolveProject(repository)).thenReturn(project);
-        when(repositoryService.createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), any())).thenReturn(repository);
-
-        final WorkspaceProject importedProject = libraryService.importProject(organizationalUnit,
-                                                                              exampleProject);
-
-        assertSame(project, importedProject);
-        final ArgumentCaptor<RepositoryEnvironmentConfigurations> configsCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
-        verify(repositoryService).createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), configsCaptor.capture());
-        final RepositoryEnvironmentConfigurations configs = configsCaptor.getValue();
-        assertEquals(repoURL, configs.getOrigin());
-        assertEquals("example", configs.getSubdirectory());
-        verify(projectService).resolveProject(repository);
+        assertEquals(importProjects,
+                     loadedImportProjects);
     }
 
     @Test
@@ -756,24 +716,6 @@ public class LibraryServiceImplTest {
                      gav.getVersion());
     }
 
-    @Test
-    public void getAllUsersTest() {
-        List<SocialUser> allUsers = new ArrayList<>();
-        allUsers.add(new SocialUser("system"));
-        allUsers.add(new SocialUser("admin"));
-        allUsers.add(new SocialUser("user"));
-        doReturn(allUsers).when(socialUserRepositoryAPI).findAllUsers();
-
-        final List<SocialUser> users = libraryService.getAllUsers();
-
-        assertEquals(2,
-                     users.size());
-        assertEquals("admin",
-                     users.get(0).getUserName());
-        assertEquals("user",
-                     users.get(1).getUserName());
-    }
-
     @Test
     public void testGetNumberOfAssets() throws Exception {
         final Path path = mock(Path.class);
@@ -788,4 +730,72 @@ public class LibraryServiceImplTest {
 
         verify(refactoringQueryService).queryHitCount(any(RefactoringPageRequest.class));
     }
+
+    @Test
+    public void addBranchTest() throws URISyntaxException {
+        final WorkspaceProject project = mock(WorkspaceProject.class);
+        doReturn(repo1).when(project).getRepository();
+        doReturn(new Space("my-space")).when(project).getSpace();
+
+        doReturn(mock(SpaceConfigStorage.class)).when(spaceConfigStorageRegistry).get("my-space");
+
+        final org.uberfire.java.nio.file.Path baseBranchPath = mock(org.uberfire.java.nio.file.Path.class);
+        final Path path = repo1.getBranches().stream().filter(b -> b.getName().equals("repo1-branch1")).findFirst().get().getPath();
+        final FileSystem fileSystem = mock(FileSystem.class);
+        final FileSystemProvider fileSystemProvider = mock(FileSystemProvider.class);
+        doReturn(fileSystemProvider).when(fileSystem).provider();
+        doReturn(fileSystem).when(baseBranchPath).getFileSystem();
+        doReturn(baseBranchPath).when(pathUtil).convert(path);
+
+        doReturn(repo1).when(repositoryService).getRepository(any());
+
+        doReturn(Optional.of(makeBranch("new-branch", "repo1"))).when(repo1).getBranch(any(Path.class));
+
+        final org.uberfire.java.nio.file.Path newBranchPath = mock(org.uberfire.java.nio.file.Path.class);
+        doReturn(newBranchPath).when(ioService).get(new URI("default://new-branch@repo1/"));
+
+        doReturn("default://new-branch@repo1/").when(pathUtil).replaceBranch(anyString(), anyString());
+
+        final ArgumentCaptor<NewBranchEvent> newBranchEventArgumentCaptor = ArgumentCaptor.forClass(NewBranchEvent.class);
+
+        libraryService.addBranch("new-branch", "repo1-branch1", project);
+
+        verify(fileSystemProvider).copy(baseBranchPath, newBranchPath);
+        verify(repositoryExternalUpdateEvent).fire(any());
+        verify(newBranchEvent).fire(newBranchEventArgumentCaptor.capture());
+
+        final NewBranchEvent newBranchEvent = newBranchEventArgumentCaptor.getValue();
+        assertEquals("new-branch", newBranchEvent.getNewBranchName());
+        assertEquals(repo1, newBranchEvent.getRepository());
+    }
+
+    @Test
+    public void removeBranchTest() {
+        final Branch masterBranch = makeBranch("master", "repo1");
+        final org.uberfire.java.nio.file.Path baseBranchPath = mock(org.uberfire.java.nio.file.Path.class);
+        final FileSystem fileSystem = mock(FileSystem.class);
+        final FileSystemProvider fileSystemProvider = mock(FileSystemProvider.class);
+        doReturn(fileSystemProvider).when(fileSystem).provider();
+        doReturn(fileSystem).when(baseBranchPath).getFileSystem();
+        doReturn(baseBranchPath).when(pathUtil).convert(masterBranch.getPath());
+
+        final WorkspaceProject project = mock(WorkspaceProject.class);
+        doReturn(repo1).when(project).getRepository();
+        doReturn(new Space("my-space")).when(project).getSpace();
+
+        doReturn(mock(SpaceConfigStorage.class)).when(spaceConfigStorageRegistry).get("my-space");
+
+        libraryService.removeBranch(project, masterBranch);
+
+        verify(ioService).delete(baseBranchPath);
+        verify(configuredRepositories).refreshRepository(repo1);
+    }
+
+    private Branch makeBranch(final String branchName,
+                              final String repoName) {
+        final Path path = mock(Path.class);
+        doReturn("default://" + branchName + "@" + repoName + "/").when(path).toURI();
+        return new Branch(branchName,
+                          path);
+    }
 }
