@@ -224,6 +224,9 @@ public class LibraryConstants {
     @TranslationKey(defaultValue = "")
     public static final String EditOrganizationalUnitContributorsSaveSuccess = "EditOrganizationalUnitContributorsSaveSuccess";
 
+    @TranslationKey(defaultValue = "")
+    public static final String EditOrganizationalUnitContributorsRemoveSuccess = "EditOrganizationalUnitContributorsRemoveSuccess";
+
     @TranslationKey(defaultValue = "")
     public static final String Add = "Add";
 
@@ -389,6 +392,9 @@ public class LibraryConstants {
     @TranslationKey(defaultValue = "")
     public static final String PreferenceDisableGAVConflictCheck_Tooltip = "PreferenceDisableGAVConflictCheck.Tooltip";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DevelopmentMode_Tooltip = "DevelopmentModeTooltip";
+
     @TranslationKey(defaultValue = "")
     public static final String ItemSuccessfullyDuplicated = "ItemSuccessfullyDuplicated";
 
@@ -460,4 +466,97 @@ public class LibraryConstants {
 
     @TranslationKey(defaultValue = "")
     public static final String DuplicatedProjectName = "DuplicatedProjectName";
+
+    @TranslationKey(defaultValue = "")
+    public static final String AddBranch = "AddBranch";
+
+    @TranslationKey(defaultValue = "")
+    public static final String AddBranchSuccess = "AddBranchSuccess";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DuplicatedBranchValidation = "DuplicatedBranchValidation";
+
+    @TranslationKey(defaultValue = "")
+    public static final String InvalidBranchName = "InvalidBranchName";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DeleteBranchDescription = "DeleteBranchDescription";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ConfirmBranchName = "ConfirmBranchName";
+
+    @TranslationKey(defaultValue = "")
+    public static final String WrongBranchConfirmedName = "WrongBranchConfirmedName";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DeletingBranch = "DeletingBranch";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DeleteBranch = "DeleteBranch";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchDeleted = "BranchDeleted";
+
+    @TranslationKey(defaultValue = "")
+    public static final String InvalidUsername = "InvalidUsername";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ContributorTypeOwner = "ContributorTypeOwner";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ContributorTypeAdmin = "ContributorTypeAdmin";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ContributorTypeContributor = "ContributorTypeContributor";
+
+    @TranslationKey(defaultValue = "")
+    public static final String SingleOwnerIsMandatory = "SingleOwnerIsMandatory";
+
+    @TranslationKey(defaultValue = "")
+    public static final String SpaceOwnerChanged = "SpaceOwnerChanged";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DuplicatedContributor = "DuplicatedContributor";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ContributorTypeNotAllowed = "ContributorTypeNotAllowed";
+
+    @TranslationKey(defaultValue = "")
+    public static final String Properties = "Properties";
+
+    @TranslationKey(defaultValue = "")
+    public static final String Testing = "Testing";
+
+    @TranslationKey(defaultValue = "")
+    public static final String Test = "Test";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchManagementReadPermissionTooltip = "BranchManagementReadPermissionTooltip";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchManagementWritePermissionTooltip = "BranchManagementWritePermissionTooltip";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchManagementDeletePermissionTooltip = "BranchManagementDeletePermissionTooltip";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchManagementDeployPermissionTooltip = "BranchManagementDeployPermissionTooltip";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchesToBeImported = "BranchesToBeImported";
+
+    @TranslationKey(defaultValue = "")
+    public static final String Ok = "Ok";
+
+    @TranslationKey(defaultValue = "")
+    public static final String MasterIsRequired = "MasterIsRequired";
+
+    @TranslationKey(defaultValue = "")
+    public static final String AtLeastMasterIsRequired = "AtLeastMasterIsRequired";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchSelectorClickToSelectBranches = "BranchSelectorClickToSelectBranches";
+
+    @TranslationKey(defaultValue = "")
+    public static final String BranchSelectorSelectedBranches = "BranchSelectorSelectedBranches";
 }
