@@ -16,11 +16,14 @@
 
 package org.kie.workbench.common.screens.projectimportsscreen.client.forms;
 
+import java.util.function.Consumer;
 import java.util.function.Supplier;
 import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
+import elemental2.promise.Promise;
 import org.guvnor.common.services.project.model.ProjectImports;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
@@ -111,21 +114,29 @@ public class ProjectImportsScreenPresenter
     }
 
     @Override
-    protected void makeMenuBar() {
-        if (canUpdateProject()) {
+    protected Promise<Void> makeMenuBar() {
+        if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
+            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+            return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
+                if (canUpdateProject) {
+                    this.fileMenuBuilder
+                            .addSave(versionRecordManager.newSaveMenuItem(this::saveAction))
+                            .addCopy(versionRecordManager.getCurrentPath(), getRenameValidator())
+                            .addRename(getSaveAndRename())
+                            .addDelete(versionRecordManager.getPathToLatest(), getRenameValidator());
+                }
 
-            this.fileMenuBuilder
-                    .addSave(versionRecordManager.newSaveMenuItem(this::saveAction))
-                    .addCopy(versionRecordManager.getCurrentPath(), getRenameValidator())
-                    .addRename(getSaveAndRename())
-                    .addDelete(versionRecordManager.getPathToLatest(), getRenameValidator());
+                addDownloadMenuItem(fileMenuBuilder);
+
+                fileMenuBuilder
+                        .addNewTopLevelMenu(versionRecordManager.buildMenu())
+                        .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+
+                return promises.resolve();
+            });
         }
 
-        addDownloadMenuItem(fileMenuBuilder);
-
-        fileMenuBuilder
-                .addNewTopLevelMenu(versionRecordManager.buildMenu())
-                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+        return promises.resolve();
     }
 
     @Override
@@ -190,8 +201,8 @@ public class ProjectImportsScreenPresenter
     }
 
     @WorkbenchMenu
-    public Menus getMenus() {
-        return menus;
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        super.getMenus(menusConsumer);
     }
 
     @OnMayClose
