@@ -30,6 +30,7 @@ import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.ErrorCallback;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.kie.server.api.model.KieContainerStatus;
+import org.kie.server.controller.api.model.events.ServerInstanceUpdated;
 import org.kie.server.controller.api.model.runtime.Container;
 import org.kie.server.controller.api.model.spec.Capability;
 import org.kie.server.controller.api.model.spec.ContainerConfig;
@@ -45,6 +46,7 @@ import org.kie.workbench.common.screens.server.management.client.events.Containe
 import org.kie.workbench.common.screens.server.management.client.events.RefreshRemoteServers;
 import org.kie.workbench.common.screens.server.management.client.events.ServerTemplateSelected;
 import org.kie.workbench.common.screens.server.management.client.util.State;
+import org.kie.workbench.common.screens.server.management.model.ContainerRuntimeOperation;
 import org.kie.workbench.common.screens.server.management.model.ContainerSpecData;
 import org.kie.workbench.common.screens.server.management.model.ContainerUpdateEvent;
 import org.kie.workbench.common.screens.server.management.service.RuntimeManagementService;
@@ -55,6 +57,7 @@ import org.uberfire.mvp.Command;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.workbench.common.screens.server.management.model.ContainerRuntimeOperation.STOP_CONTAINER;
 
 @Dependent
 public class ContainerPresenter {
@@ -106,6 +109,10 @@ public class ContainerPresenter {
         return view;
     }
 
+    protected void setContainerSpec(ContainerSpec containerSpec){
+        this.containerSpec = containerSpec;
+    }
+
     public void onRefresh(@Observes final RefreshRemoteServers refresh) {
         if (refresh != null && refresh.getContainerSpecKey() != null) {
             load(refresh.getContainerSpecKey());
@@ -123,10 +130,19 @@ public class ContainerPresenter {
         }
     }
 
+    public void onInstanceUpdated(@Observes ServerInstanceUpdated instanceUpdated) {
+        if (instanceUpdated != null && containerSpec.getServerTemplateKey().getId().equals(instanceUpdated.getServerInstance().getServerTemplateId())) {
+            load(containerSpec);
+        }
+    }
+
     public void loadContainers(@Observes final ContainerSpecData content) {
         if (content != null &&
                 content.getContainerSpec() != null &&
-                content.getContainers() != null) {
+                content.getContainers() != null &&
+                containerSpec != null &&
+                containerSpec.getId() != null &&
+                containerSpec.getId().equals(content.getContainerSpec().getId())) {
             setup(content.getContainerSpec(),
                   content.getContainers());
         } else {
@@ -135,7 +151,11 @@ public class ContainerPresenter {
     }
 
     public void refreshOnContainerUpdateEvent(@Observes final ContainerUpdateEvent updateEvent) {
-        refresh();
+        final ContainerRuntimeOperation runtimeOperation = updateEvent.getContainerRuntimeOperation();
+
+        if (updateEvent.getContainerSpec().equals(containerSpec) && runtimeOperation != STOP_CONTAINER) {
+            refresh();
+        }
     }
 
     public void refresh() {
@@ -146,6 +166,7 @@ public class ContainerPresenter {
         checkNotNull("containerSpecKey", containerSpecKey);
         runtimeManagementService.call((RemoteCallback<ContainerSpecData>) content -> {
             checkNotNull("content", content);
+            setContainerSpec(content.getContainerSpec());
             loadContainers(content);
         }).getContainersByContainerSpec(containerSpecKey.getServerTemplateKey().getId(),
                                         containerSpecKey.getId());
@@ -198,20 +219,31 @@ public class ContainerPresenter {
         return true;
     }
 
-    private void updateStatus(final KieContainerStatus status) {
+    protected void updateStatus(final KieContainerStatus status) {
         switch (status) {
             case CREATING:
             case STARTED:
                 view.disableRemoveButton();
                 view.setContainerStartState(State.ENABLED);
                 view.setContainerStopState(State.DISABLED);
+                view.updateToggleActivationButton(false);
+                view.enableToggleActivationButton();
                 break;
+            case DEACTIVATED:
+                view.disableRemoveButton();
+                view.setContainerStartState(State.ENABLED);
+                view.setContainerStopState(State.DISABLED);
+                view.updateToggleActivationButton(true);
+                view.enableToggleActivationButton();
+                break;                
             case STOPPED:
+                view.updateToggleActivationButton(false);
             case DISPOSING:
             case FAILED:
                 view.enableRemoveButton();
                 view.setContainerStartState(State.DISABLED);
                 view.setContainerStopState(State.ENABLED);
+                view.disableToggleActivationButton();
                 break;
         }
     }
@@ -290,6 +322,45 @@ public class ContainerPresenter {
                                        }
                                    }).startContainer(containerSpec);
     }
+    
+    public void toggleActivationContainer() {
+        if (containerSpec.getStatus().equals(KieContainerStatus.DEACTIVATED)) {
+            specManagementService.call(new RemoteCallback<Void>() {
+                                           @Override
+                                           public void callback(final Void response) {
+                                               updateStatus(KieContainerStatus.STARTED);
+                                           }
+                                       },
+                                       new ErrorCallback<Object>() {
+                                           @Override
+                                           public boolean error(final Object o,
+                                                                final Throwable throwable) {
+                                               notification.fire(new NotificationEvent(view.getStartContainerErrorMessage(),
+                                                                                       NotificationEvent.NotificationType.ERROR));
+                                               updateStatus(KieContainerStatus.DEACTIVATED);
+                                               return false;
+                                           }
+                                       }).activateContainer(containerSpec);
+        } else if (containerSpec.getStatus().equals(KieContainerStatus.STARTED)) {
+         
+            specManagementService.call(new RemoteCallback<Void>() {
+                                           @Override
+                                           public void callback(final Void response) {
+                                               updateStatus(KieContainerStatus.DEACTIVATED);
+                                           }
+                                       },
+                                       new ErrorCallback<Object>() {
+                                           @Override
+                                           public boolean error(final Object o,
+                                                                final Throwable throwable) {
+                                               notification.fire(new NotificationEvent(view.getStartContainerErrorMessage(),
+                                                                                       NotificationEvent.NotificationType.ERROR));
+                                               updateStatus(KieContainerStatus.STARTED);
+                                               return false;
+                                           }
+                                       }).deactivateContainer(containerSpec);
+        }
+    }
 
     public interface View extends UberView<ContainerPresenter> {
 
@@ -299,6 +370,12 @@ public class ContainerPresenter {
 
         void enableRemoveButton();
 
+        void updateToggleActivationButton(boolean activate);
+        
+        void disableToggleActivationButton();
+        
+        void enableToggleActivationButton();
+        
         void setContainerName(final String containerName);
 
         void setGroupIp(final String groupIp);
