@@ -16,9 +16,14 @@
 
 package org.kie.workbench.common.stunner.client.widgets.presenters.session.impl;
 
+import java.lang.annotation.Annotation;
 import java.util.Optional;
 import java.util.function.Predicate;
 
+import javax.enterprise.event.Event;
+
+import org.kie.workbench.common.stunner.client.widgets.event.SessionFocusedEvent;
+import org.kie.workbench.common.stunner.client.widgets.event.SessionLostFocusEvent;
 import org.kie.workbench.common.stunner.client.widgets.notification.CommandNotification;
 import org.kie.workbench.common.stunner.client.widgets.notification.Notification;
 import org.kie.workbench.common.stunner.client.widgets.notification.NotificationContext;
@@ -29,23 +34,30 @@ import org.kie.workbench.common.stunner.client.widgets.palette.PaletteWidget;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionViewer;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.Toolbar;
-import org.kie.workbench.common.stunner.client.widgets.toolbar.ToolbarFactory;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasFocusedEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasLostFocusEvent;
 import org.kie.workbench.common.stunner.core.client.components.palette.PaletteDefinition;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientReadOnlySession;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.AbstractSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 
 public abstract class AbstractSessionPresenter<D extends Diagram, H extends AbstractCanvasHandler,
-        S extends AbstractClientReadOnlySession, E extends SessionViewer<S, H, D>>
+        S extends AbstractSession, E extends SessionViewer<S, H, D>>
         implements SessionPresenter<S, H, D> {
 
+    private final DefinitionUtils definitionUtils;
     private final SessionManager sessionManager;
-    private final Optional<ToolbarFactory<S>> toolbarFactory;
-    private final Optional<DefaultPaletteFactory<H>> paletteFactory;
+    private final DefaultPaletteFactory<H> paletteFactory;
     private final SessionPresenter.View view;
     private final NotificationsObserver notificationsObserver;
+    private final Event<SessionFocusedEvent> sessionFocusedEvent;
+    private final Event<CanvasFocusedEvent> canvasFocusedEvent;
+    private final Event<SessionLostFocusEvent> sessionLostFocusEvent;
+    private final Event<CanvasLostFocusEvent> canvasLostFocusEventEvent;
 
     private D diagram;
     private Toolbar<S> toolbar;
@@ -55,15 +67,23 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
     private Optional<Predicate<Notification.Type>> typePredicate;
 
     @SuppressWarnings("unchecked")
-    protected AbstractSessionPresenter(final SessionManager sessionManager,
+    protected AbstractSessionPresenter(final DefinitionUtils definitionUtils,
+                                       final SessionManager sessionManager,
                                        final SessionPresenter.View view,
-                                       final Optional<? extends ToolbarFactory<S>> toolbarFactory,
-                                       final Optional<DefaultPaletteFactory<H>> paletteFactory,
-                                       final NotificationsObserver notificationsObserver) {
+                                       final DefaultPaletteFactory<H> paletteFactory,
+                                       final NotificationsObserver notificationsObserver,
+                                       final Event<SessionFocusedEvent> sessionFocusedEvent,
+                                       final Event<CanvasFocusedEvent> canvasFocusedEvent,
+                                       final Event<SessionLostFocusEvent> sessionLostFocusEvent,
+                                       final Event<CanvasLostFocusEvent> canvasLostFocusEventEvent) {
+        this.definitionUtils = definitionUtils;
         this.sessionManager = sessionManager;
-        this.toolbarFactory = (Optional<ToolbarFactory<S>>) toolbarFactory;
         this.paletteFactory = paletteFactory;
         this.notificationsObserver = notificationsObserver;
+        this.sessionFocusedEvent = sessionFocusedEvent;
+        this.sessionLostFocusEvent = sessionLostFocusEvent;
+        this.canvasFocusedEvent = canvasFocusedEvent;
+        this.canvasLostFocusEventEvent = canvasLostFocusEventEvent;
         this.view = view;
         this.hasToolbar = true;
         this.hasPalette = true;
@@ -72,33 +92,41 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
 
     public abstract E getDisplayer();
 
+    protected abstract Class<? extends AbstractSession> getSessionType();
+
+    protected abstract Toolbar<S> newToolbar(Annotation qualifier);
+
+    protected abstract void destroyToolbarInstace(Toolbar<S> toolbar);
+
     @Override
+    @SuppressWarnings("unchecked")
     public void open(final D diagram,
-                     final S session,
-                     final SessionPresenterCallback<S, D> callback) {
+                     final SessionPresenterCallback<D> callback) {
         this.diagram = diagram;
         notificationsObserver.onCommandExecutionFailed(this::showCommandError);
         notificationsObserver.onValidationSuccess(this::showNotificationMessage);
         notificationsObserver.onValidationFailed(this::showValidationError);
-        open(session,
-             callback);
+        sessionManager.newSession(diagram.getMetadata(),
+                                  getSessionType(),
+                                  session -> open((S) session,
+                                                  callback));
     }
 
-    public void open(final S item,
-                     final SessionPresenterCallback<S, D> callback) {
-        beforeOpen(item);
-        getDisplayer().open(item,
-                            new SessionViewer.SessionViewerCallback<S, D>() {
+    public void open(final S session,
+                     final SessionPresenterCallback<D> callback) {
+        beforeOpen(session);
+        getDisplayer().open(session,
+                            new SessionViewer.SessionViewerCallback<D>() {
                                 @Override
                                 public void afterCanvasInitialized() {
                                     callback.afterCanvasInitialized();
-                                    sessionManager.open(getInstance());
+                                    sessionManager.open(session);
                                     callback.afterSessionOpened();
                                 }
 
                                 @Override
                                 public void onSuccess() {
-                                    onSessionOpened(item);
+                                    onSessionOpened(session);
                                     callback.onSuccess();
                                 }
 
@@ -110,25 +138,25 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
                             });
     }
 
-    public void open(final S item,
+    public void open(final S session,
                      final int width,
                      final int height,
-                     final SessionPresenterCallback<S, D> callback) {
-        beforeOpen(item);
-        getDisplayer().open(item,
+                     final SessionPresenterCallback<D> callback) {
+        beforeOpen(session);
+        getDisplayer().open(session,
                             width,
                             height,
-                            new SessionViewer.SessionViewerCallback<S, D>() {
+                            new SessionViewer.SessionViewerCallback<D>() {
                                 @Override
                                 public void afterCanvasInitialized() {
                                     callback.afterCanvasInitialized();
-                                    sessionManager.open(getInstance());
+                                    sessionManager.open(session);
                                     callback.afterSessionOpened();
                                 }
 
                                 @Override
                                 public void onSuccess() {
-                                    onSessionOpened(item);
+                                    onSessionOpened(session);
                                     callback.onSuccess();
                                 }
 
@@ -164,6 +192,17 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
         return this;
     }
 
+    @Override
+    public void focus() {
+        getSession().ifPresent(sessionManager::open);
+        getSession().ifPresent(this::fireSessionFocused);
+    }
+
+    @Override
+    public void lostFocus() {
+        getSession().ifPresent(this::fireSessionLostFocus);
+    }
+
     public void scale(final int width,
                       final int height) {
         getDisplayer().scale(width,
@@ -171,11 +210,11 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
     }
 
     public void clear() {
-        if (null != getPalette()) {
-            getPalette().unbind();
+        if (null != palette) {
+            palette.unbind();
         }
-        if (null != getToolbar()) {
-            getToolbar().clear();
+        if (null != toolbar) {
+            destroyToolbar();
         }
         getDisplayer().clear();
         diagram = null;
@@ -185,7 +224,7 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
     public void destroy() {
         destroyToolbar();
         destroyPalette();
-        sessionManager.destroy();
+        getSession().ifPresent(sessionManager::destroy);
         getDisplayer().destroy();
         getView().destroy();
         diagram = null;
@@ -195,6 +234,10 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
         return getDisplayer().getInstance();
     }
 
+    public Optional<S> getSession() {
+        return Optional.ofNullable(getInstance());
+    }
+
     @Override
     public Toolbar<S> getToolbar() {
         return toolbar;
@@ -214,6 +257,10 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
         return getDisplayer().getHandler();
     }
 
+    protected D getDiagram() {
+        return diagram;
+    }
+
     protected void beforeOpen(final S item) {
         getView().showLoading(true);
     }
@@ -222,18 +269,50 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
     protected void onSessionOpened(final S session) {
         destroyToolbar();
         destroyPalette();
-        if (hasToolbar) {
-            toolbar = buildToolbar(session);
-            getView().setToolbarWidget(toolbar.getView());
-        }
-        if (hasPalette) {
-            this.palette = (PaletteWidget<PaletteDefinition>) buildPalette(session);
-            getView().setPaletteWidget(getPalette());
-        }
+        initToolbar(session);
+        initPalette(session);
         getView().setCanvasWidget(getDisplayer().getView());
         getView().showLoading(false);
     }
 
+    private void fireSessionLostFocus(final ClientSession session) {
+        sessionLostFocusEvent.fire(new SessionLostFocusEvent(session));
+        canvasLostFocusEventEvent.fire(new CanvasLostFocusEvent(session.getCanvas()));
+    }
+
+    private void fireSessionFocused(final ClientSession session) {
+        sessionFocusedEvent.fire(new SessionFocusedEvent(session));
+        canvasFocusedEvent.fire(new CanvasFocusedEvent(session.getCanvas()));
+    }
+
+    @SuppressWarnings("unchecked")
+    private void initToolbar(final S session) {
+        if (hasToolbar) {
+            final Annotation qualifier =
+                    definitionUtils.getQualifier(session.getCanvasHandler().getDiagram().getMetadata().getDefinitionSetId());
+            toolbar = newToolbar(qualifier);
+            if (null != toolbar) {
+                toolbar.load(session);
+            }
+            getView().setToolbarWidget(toolbar.getView());
+        }
+    }
+
+    @SuppressWarnings("unchecked")
+    private void initPalette(final S session) {
+        if (hasPalette) {
+            palette = (PaletteWidget<PaletteDefinition>) buildPalette(session);
+            if (null != palette) {
+                getView().setPaletteWidget(palette);
+            }
+        }
+    }
+
+    public void refresh() {
+        destroyPalette();
+        getSession().ifPresent(this::initPalette);
+    }
+
     private void showMessage(final String message) {
         if (isDisplayNotifications()) {
             getView().showMessage(message);
@@ -259,33 +338,26 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
         }
     }
 
-    private Toolbar<S> buildToolbar(final S session) {
-        if (!toolbarFactory.isPresent()) {
-            throw new UnsupportedOperationException("This session presenter with type [" + this.getClass().getName() + "] does not supports the toolbar.");
-        }
-        return toolbarFactory.get().build(session);
-    }
-
     @SuppressWarnings("unchecked")
     private PaletteWidget<? extends PaletteDefinition> buildPalette(final S session) {
-        if (!paletteFactory.isPresent()) {
-            throw new UnsupportedOperationException("This session presenter with type [" + this.getClass().getName() + "] does not supports the palette.");
+        if (null != paletteFactory) {
+            return paletteFactory.newPalette((H) session.getCanvasHandler());
         }
-        return paletteFactory.get()
-                .newPalette((H) session.getCanvasHandler());
+        return null;
     }
 
     private void destroyToolbar() {
-        if (null != getToolbar()) {
-            getToolbar().destroy();
+        if (null != toolbar) {
+            toolbar.destroy();
+            destroyToolbarInstace(toolbar);
             toolbar = null;
         }
     }
 
     private void destroyPalette() {
-        if (null != getPalette()) {
-            getPalette().unbind();
-            getPalette().destroy();
+        if (null != palette) {
+            palette.destroy();
+            palette = null;
         }
     }
 
@@ -320,14 +392,6 @@ public abstract class AbstractSessionPresenter<D extends Diagram, H extends Abst
         }
     }
 
-    protected D getDiagram() {
-        return diagram;
-    }
-
-    protected SessionManager getSessionManager() {
-        return sessionManager;
-    }
-
     private boolean isDisplayNotifications() {
         return typePredicate
                 .orElse(t -> false)
