@@ -17,6 +17,8 @@
 package org.kie.workbench.common.stunner.core.client.definition.adapter.binding;
 
 import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
 import java.util.Set;
 
 import org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils;
@@ -60,6 +62,14 @@ class ClientBindablePropertySetAdapter extends AbstractClientBindableAdapter<Obj
                              getPropertiesFieldNames().get(pojo.getClass()));
     }
 
+    @Override
+    public Optional<?> getProperty(Object pojo, String propertyName) {
+        return getPropertiesFieldNames().get(pojo.getClass()).stream()
+                .filter(name -> Objects.equals(name, propertyName))
+                .findFirst()
+                .map(prop -> getProxiedValue(pojo, prop));
+    }
+
     @Override
     public boolean accepts(final Class<?> pojoClass) {
         return getPropertiesFieldNames().containsKey(pojoClass);
