@@ -35,13 +35,21 @@ public class ClientTranslationService extends AbstractTranslationService {
     }
 
     @Override
-    public String getKeyValue(final String key) {
+    public String getValue(final String key) {
         return erraiTranslationService.getTranslation(key);
     }
 
+    public String getNotNullValue(final String key) {
+        final String value = getValue(key);
+        if (null == value) {
+            return key;
+        }
+        return value;
+    }
+
     @Override
-    public String getKeyValue(final String key,
-                                 final Object... args) {
+    public String getValue(final String key,
+                           final Object... args) {
         return erraiTranslationService.format(key,
                                               args);
     }
