@@ -25,37 +25,36 @@ import javax.inject.Inject;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ClipboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ContainmentAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.DockingAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.LocationControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.MediatorsControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ResizeControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ToolboxControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.CanvasInPlaceTextEditorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.MultiLineTextEditorBox;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.EdgeBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.ElementBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.NodeBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.impl.Observer;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ControlPointControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.drag.LocationControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.AbstractCanvasShortcutsControlImpl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.pan.PanControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.resize.ResizeControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.MultipleSelection;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.toolbox.ToolboxControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.Request;
 import org.kie.workbench.common.stunner.core.client.command.RequiresCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.preferences.StunnerPreferencesRegistry;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Element;
-import org.kie.workbench.common.stunner.core.registry.RegistryFactory;
 import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
+import org.kie.workbench.common.stunner.core.registry.impl.ClientCommandRegistry;
 import org.uberfire.mvp.Command;
 
 @Dependent
@@ -66,22 +65,19 @@ public class DefaultEditorSession
     private final CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager;
     private final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
     private final SessionCommandManager<AbstractCanvasHandler> requestCommandManager;
-    private final StunnerPreferencesRegistry stunnerPreferencesRegistry;
     private final CommandRegistry<org.kie.workbench.common.stunner.core.command.Command<AbstractCanvasHandler, CanvasViolation>> commandRegistry;
 
     @Inject
     public DefaultEditorSession(final ManagedSession session,
-                                final RegistryFactory registryFactory,
                                 final CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager,
                                 final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                                 final @Request SessionCommandManager<AbstractCanvasHandler> requestCommandManager,
-                                final StunnerPreferencesRegistry stunnerPreferencesRegistry) {
+                                final ClientCommandRegistry<org.kie.workbench.common.stunner.core.command.Command<AbstractCanvasHandler, CanvasViolation>> clientCommandRegistry) {
         this.session = session;
-        this.commandRegistry = registryFactory.newCommandRegistry();
+        this.commandRegistry = clientCommandRegistry;
         this.sessionCommandManager = sessionCommandManager;
         this.requestCommandManager = requestCommandManager;
         this.canvasCommandManager = canvasCommandManager;
-        this.stunnerPreferencesRegistry = stunnerPreferencesRegistry;
     }
 
     @PostConstruct
@@ -95,26 +91,25 @@ public class DefaultEditorSession
     @Override
     public void init(final Metadata metadata,
                      final Command callback) {
-        init(s ->
-                     s.registerCanvasControl(ZoomControl.class)
-                             .registerCanvasControl(PanControl.class)
-                             .registerCanvasHandlerControl(SelectionControl.class,
-                                                           MultipleSelection.class)
-                             .registerCanvasHandlerControl(ResizeControl.class)
-                             .registerCanvasHandlerControl(ConnectionAcceptorControl.class)
-                             .registerCanvasHandlerControl(ContainmentAcceptorControl.class)
-                             .registerCanvasHandlerControl(DockingAcceptorControl.class)
-                             .registerCanvasHandlerControl(CanvasInPlaceTextEditorControl.class,
-                                                           MultiLineTextEditorBox.class)
-                             .registerCanvasHandlerControl(LocationControl.class)
-                             .registerCanvasHandlerControl(ToolboxControl.class)
-                             .registerCanvasHandlerControl(ElementBuilderControl.class,
-                                                           Observer.class)
-                             .registerCanvasHandlerControl(NodeBuilderControl.class)
-                             .registerCanvasHandlerControl(EdgeBuilderControl.class)
-                             .registerCanvasControl(KeyboardControl.class)
-                             .registerCanvasControl(ClipboardControl.class)
-                             .registerCanvasHandlerControl(ControlPointControl.class),
+        init(s -> s.registerCanvasControl(MediatorsControl.class)
+                     .registerCanvasHandlerControl(SelectionControl.class,
+                                                   MultipleSelection.class)
+                     .registerCanvasHandlerControl(ResizeControl.class)
+                     .registerCanvasHandlerControl(ConnectionAcceptorControl.class)
+                     .registerCanvasHandlerControl(ContainmentAcceptorControl.class)
+                     .registerCanvasHandlerControl(DockingAcceptorControl.class)
+                     .registerCanvasHandlerControl(CanvasInPlaceTextEditorControl.class,
+                                                   MultiLineTextEditorBox.class)
+                     .registerCanvasHandlerControl(LocationControl.class)
+                     .registerCanvasHandlerControl(ToolboxControl.class)
+                     .registerCanvasHandlerControl(ElementBuilderControl.class,
+                                                   Observer.class)
+                     .registerCanvasHandlerControl(NodeBuilderControl.class)
+                     .registerCanvasHandlerControl(EdgeBuilderControl.class)
+                     .registerCanvasHandlerControl(AbstractCanvasShortcutsControlImpl.class)
+                     .registerCanvasControl(KeyboardControl.class)
+                     .registerCanvasControl(ClipboardControl.class)
+                     .registerCanvasHandlerControl(ControlPointControl.class),
              metadata,
              callback);
     }
@@ -168,13 +163,8 @@ public class DefaultEditorSession
     }
 
     @Override
-    public ZoomControl<AbstractCanvas> getZoomControl() {
-        return (ZoomControl<AbstractCanvas>) session.getCanvasControl(ZoomControl.class);
-    }
-
-    @Override
-    public PanControl<AbstractCanvas> getPanControl() {
-        return (PanControl<AbstractCanvas>) session.getCanvasControl(PanControl.class);
+    public MediatorsControl<AbstractCanvas> getMediatorsControl() {
+        return (MediatorsControl<AbstractCanvas>) session.getCanvasControl(MediatorsControl.class);
     }
 
     @Override
@@ -213,6 +203,7 @@ public class DefaultEditorSession
             // TODO: Improve this
             if (control instanceof LocationControl ||
                     control instanceof ConnectionAcceptorControl ||
+                    control instanceof ControlPointControl ||
                     control instanceof DockingAcceptorControl ||
                     control instanceof ContainmentAcceptorControl) {
                 ((RequiresCommandManager) control).setCommandManagerProvider(() -> requestCommandManager);
