@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.core.client.session.command.impl;
 
+import java.lang.annotation.Annotation;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
@@ -25,7 +26,7 @@ import java.util.function.Consumer;
 
 import javax.enterprise.event.Event;
 
-import org.junit.Assert;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -35,7 +36,7 @@ import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.CloneConnectorCommand;
 import org.kie.workbench.common.stunner.core.client.canvas.command.CloneNodeCommand;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.LocalClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
@@ -51,11 +52,11 @@ import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
+import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
+import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.kie.workbench.common.stunner.core.util.UUID;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
@@ -107,9 +108,6 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
     @Mock
     private ClipboardControl<Element, AbstractCanvas, ClientSession> clipboardControl;
 
-    @Mock
-    private SessionCommandFactory sessionCommandFactory;
-
     @Mock
     private Event<CanvasSelectionEvent> selectionEvent;
 
@@ -159,11 +157,23 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
     @Mock
     private org.uberfire.mvp.Command statusCallback;
 
+    @Mock
+    private DefinitionUtils definitionUtils;
+
+    private final String DEFINITION_SET_ID = "mockDefinitionSetId";
+
+    @Mock
+    private Annotation qualifier;
+
+    @Mock
+    private ManagedInstance<CanvasCommandFactory<AbstractCanvasHandler>> canvasCommandFactoryInstance;
+
     private static final String CLONE_UUID = UUID.uuid();
 
     private static final String CLONE2_UUID = UUID.uuid();
 
     @Before
+    @SuppressWarnings("unchecked")
     public void setUp() throws Exception {
         clipboardControl = spy(new LocalClipboardControl());
 
@@ -175,7 +185,7 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
         node2.setContent(view);
         when(session.getCanvasHandler()).thenReturn(canvasHandler);
         when(canvasHandler.getGraphIndex()).thenReturn(graphMockHandler.graphIndex);
-        when(view.getBounds()).thenReturn(new BoundsImpl(new BoundImpl(X, Y), new BoundImpl(X + NODE_SIZE, Y + NODE_SIZE)));
+        when(view.getBounds()).thenReturn(Bounds.create(X, Y, X + NODE_SIZE, Y + NODE_SIZE));
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(diagram.getMetadata()).thenReturn(metadata);
         when(metadata.getCanvasRootUUID()).thenReturn(CANVAS_UUID);
@@ -186,7 +196,6 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
         when(clone.getUUID()).thenReturn(CLONE_UUID);
         when(clone2.getUUID()).thenReturn(CLONE2_UUID);
         when(session.getClipboardControl()).thenReturn(clipboardControl);
-        when(sessionCommandFactory.newCopySelectionCommand()).thenReturn(copySelectionSessionCommand);
         when(sessionCommandManager.getRegistry()).thenReturn(commandRegistry);
 
         cloneMap = new HashMap() {{
@@ -196,10 +205,17 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
 
         super.setup();
         this.pasteSelectionSessionCommand = getCommand();
+
+        when(metadata.getDefinitionSetId()).thenReturn(DEFINITION_SET_ID);
+        when(definitionUtils.getQualifier(eq(DEFINITION_SET_ID))).thenReturn(qualifier);
+        when(canvasCommandFactoryInstance.select(eq(qualifier))).thenReturn(canvasCommandFactoryInstance);
+        when(canvasCommandFactoryInstance.isUnsatisfied()).thenReturn(false);
+        when(canvasCommandFactoryInstance.get()).thenReturn(canvasCommandFactory);
     }
 
     @Test
-    public void execute() throws Exception {
+    @SuppressWarnings("unchecked")
+    public void execute() {
         pasteSelectionSessionCommand.bind(session);
 
         //Mock the callback of CloneNodeCommand
@@ -252,7 +268,8 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
     }
 
     @Test
-    public void executeWithMultiSelection() throws Exception {
+    @SuppressWarnings("unchecked")
+    public void executeWithMultiSelection() {
         pasteSelectionSessionCommand.bind(session);
 
         //Mock the callback of CloneNodeCommand
@@ -303,13 +320,14 @@ public class PasteSelectionSessionCommandTest extends BaseSessionCommandKeyboard
         ArgumentCaptor<Command> commandArgumentCaptor = ArgumentCaptor.forClass(Command.class);
         verify(commandRegistry, times(1)).register(commandArgumentCaptor.capture());
         assertTrue(commandArgumentCaptor.getValue() instanceof CompositeCommand);
-        assertEquals(((CompositeCommand)commandArgumentCaptor.getValue()).size(), 2);
+        assertEquals(((CompositeCommand) commandArgumentCaptor.getValue()).size(), 2);
     }
 
     @Override
     protected PasteSelectionSessionCommand getCommand() {
-        return new PasteSelectionSessionCommand(sessionCommandManager, canvasCommandFactory,
-                                                selectionEvent, sessionCommandFactory);
+        return new PasteSelectionSessionCommand(sessionCommandManager, canvasCommandFactoryInstance,
+                                                selectionEvent, copySelectionSessionCommand,
+                                                definitionUtils);
     }
 
     @Override
