@@ -17,14 +17,19 @@
 package org.kie.workbench.common.stunner.core;
 
 import java.util.Collections;
+import java.util.List;
 import java.util.Optional;
 import java.util.Set;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
 
+import org.kie.soup.commons.util.Sets;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
+import org.kie.workbench.common.stunner.core.rule.RuleSet;
+import org.kie.workbench.common.stunner.core.rule.context.EdgeCardinalityContext;
+import org.kie.workbench.common.stunner.core.rule.impl.CanConnect;
+import org.kie.workbench.common.stunner.core.rule.impl.EdgeOccurrences;
+import org.kie.workbench.common.stunner.core.rule.impl.Occurrences;
 
 /**
  * An utility class for testing scope that provides some "real" (not mocked) graph's initial
@@ -33,17 +38,18 @@ import org.kie.workbench.common.stunner.core.graph.Node;
 public class TestingGraphInstanceBuilder {
 
     public static final String DEF0_ID = "def0";
-    public static final Set<String> DEF0_LABELS = Collections.singleton("label0");
+    public static final Set<String> DEF0_LABELS = new Sets.Builder<String>().add("label0").add("all").build();
+    //public static final Set<String> DEF0_LABELS = Collections.singleton("label0");
     public static final String DEF1_ID = "def1";
-    public static final Set<String> DEF1_LABELS = Collections.singleton("label1");
+    public static final Set<String> DEF1_LABELS = new Sets.Builder<String>().add("label1").add("all").build();
     public static final String DEF2_ID = "def2";
-    public static final Set<String> DEF2_LABELS = Stream.of("label2, dockLabel").collect(Collectors.toSet());
+    public static final Set<String> DEF2_LABELS = new Sets.Builder<String>().add("label2").add("dockLabel").add("all").build();
     public static final String DEF3_ID = "def3";
-    public static final Set<String> DEF3_LABELS = Collections.singleton("label3");
+    public static final Set<String> DEF3_LABELS = new Sets.Builder<String>().add("label3").add("all").build();
     public static final String DEF4_ID = "def4";
-    public static final Set<String> DEF4_LABELS = Collections.singleton("label4");
+    public static final Set<String> DEF4_LABELS = new Sets.Builder<String>().add("label4").add("all").build();
     public static final String DEF5_ID = "def5";
-    public static final Set<String> DEF5_LABELS = Stream.of("label4", "dockLabel").collect(Collectors.toSet());
+    public static final Set<String> DEF5_LABELS = new Sets.Builder<String>().add("label4").add("dockLabel").add("all").build();
 
     public static final String EDGE1_ID = "edge11d";
     public static final String EDGE2_ID = "edge21d";
@@ -155,10 +161,10 @@ public class TestingGraphInstanceBuilder {
      * --------------------------------------------
      * |                     |                     |
      * startNode --(edge1)--> intermNode --(edge2)--> endNode
-     *                           |
-     *                        (edge3)
-     *                           |
-     *                       dockedNode
+     * |
+     * (edge3)
+     * |
+     * dockedNode
      */
     public static class TestGraph4 extends TestGraph2 {
 
@@ -183,6 +189,33 @@ public class TestingGraphInstanceBuilder {
         return buildTestGraph4(handler);
     }
 
+    /**
+     * **********
+     * * Graph5 *
+     * **********
+     * <p>
+     * Structure:
+     * -                 parentNode
+     * ----------------------------------------------------------------
+     * |                     |                                        |
+     * startNode --(edge1)--> intermNode --(edge2)--> intermNode   endNode
+     */
+    public static class TestGraph5 {
+
+        public Graph graph;
+        public Node parentNode;
+        public Node startNode;
+        public Node intermNode;
+        public Node endNode;
+        public Edge edge1;
+        public Edge edge2;
+        public int evaluationsCount;
+    }
+
+    public static TestGraph5 newGraph5(final TestingGraphMockHandler handler) {
+        return buildTestGraph5(handler);
+    }
+
     /*
      ************ PRIVATE BUILDER METHODS ******************
      */
@@ -224,10 +257,35 @@ public class TestingGraphInstanceBuilder {
                          result.intermNode)
                 .connectTo(result.edge2,
                            result.endNode);
-        result.evaluationsCount = 18;
+        result.evaluationsCount = 14;
         return result;
     }
 
+    @SuppressWarnings("unchecked")
+    public static void createDefaultRulesForGraph1(RuleSet ruleSet) {
+        List rules = (List) ruleSet.getRules();
+        String def1Label = "label1";
+        String def2Label = "label2";
+        rules.add(new CanConnect("connectionFromStartToIntermediateForEdge1",
+                                 EDGE1_ID,
+                                 Collections.singletonList(new CanConnect.PermittedConnection(def1Label,
+                                                                                              def2Label))));
+        rules.add(new EdgeOccurrences("Edge1Cardinality",
+                                      EDGE1_ID,
+                                      def1Label,
+                                      EdgeCardinalityContext.Direction.OUTGOING,
+                                      -1,
+                                      -1));
+        rules.add(new Occurrences("graphCardinalityForDef1",
+                                  def1Label,
+                                  -1,
+                                  -1));
+        rules.add(new Occurrences("graphCardinalityForDef2",
+                                  def2Label,
+                                  -1,
+                                  -1));
+    }
+
     private static TestGraph2 buildTestGraph2(final TestingGraphMockHandler graphTestHandler) {
         TestGraph2 result = new TestGraph2();
         result.graph = graphTestHandler.graph;
@@ -270,7 +328,7 @@ public class TestingGraphInstanceBuilder {
                          result.intermNode)
                 .connectTo(result.edge2,
                            result.endNode);
-        result.evaluationsCount = 23;
+        result.evaluationsCount = 19;
         return result;
     }
 
@@ -285,7 +343,6 @@ public class TestingGraphInstanceBuilder {
                 graphTestHandler.newNode(CONTAINER_NODE_UUID,
                                          DEF4_ID,
                                          Optional.of(DEF4_LABELS));
-
         result.startNode =
                 graphTestHandler.newNode(START_NODE_UUID,
                                          DEF1_ID,
@@ -336,7 +393,54 @@ public class TestingGraphInstanceBuilder {
 
         result.edge3 = graphTestHandler.newEdge(EDGE3_UUID, EDGE3_ID, Optional.of(DEF4_LABELS));
         graphTestHandler.dockTo(result.intermNode, result.dockedNode);
+        graphTestHandler.setChild(result.parentNode, result.dockedNode);
 
         return result;
     }
+
+    private static TestGraph5 buildTestGraph5(final TestingGraphMockHandler graphTestHandler) {
+        TestGraph5 result = new TestGraph5();
+        result.graph = graphTestHandler.graph;
+        result.parentNode =
+                graphTestHandler.newNode(PARENT_NODE_UUID,
+                                         DEF0_ID,
+                                         Optional.of(DEF0_LABELS));
+        result.startNode =
+                graphTestHandler.newNode(START_NODE_UUID,
+                                         DEF1_ID,
+                                         Optional.of(DEF1_LABELS));
+        result.intermNode =
+                graphTestHandler.newNode(INTERM_NODE_UUID,
+                                         DEF2_ID,
+                                         Optional.of(DEF2_LABELS));
+        result.endNode =
+                graphTestHandler.newNode(END_NODE_UUID,
+                                         DEF3_ID,
+                                         Optional.of(DEF3_LABELS));
+        result.edge1 =
+                graphTestHandler.newEdge(EDGE1_UUID,
+                                         EDGE1_ID,
+                                         Optional.empty());
+        result.edge2 =
+                graphTestHandler.newEdge(EDGE2_UUID,
+                                         EDGE2_ID,
+                                         Optional.empty());
+        graphTestHandler
+                .setChild(result.parentNode,
+                          result.startNode)
+                .setChild(result.parentNode,
+                          result.intermNode)
+                .setChild(result.parentNode,
+                          result.endNode)
+                .addEdge(result.edge1,
+                         result.startNode)
+                .connectTo(result.edge1,
+                           result.intermNode)
+                .addEdge(result.edge2,
+                         result.intermNode)
+                .connectTo(result.edge2,
+                           result.intermNode);
+        result.evaluationsCount = 19;
+        return result;
+    }
 }
