@@ -21,10 +21,13 @@ import javax.enterprise.context.ApplicationScoped;
 import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess;
+import org.kie.workbench.common.stunner.bpmn.definition.Association;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
 import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
 import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
+import org.kie.workbench.common.stunner.bpmn.definition.EndCompensationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EndEscalationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndSignalEvent;
@@ -32,7 +35,12 @@ import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EventSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ExclusiveGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.InclusiveGateway;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEventThrowing;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateConditionalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEventThrowing;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventThrowing;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
@@ -45,7 +53,10 @@ import org.kie.workbench.common.stunner.bpmn.definition.ParallelGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.ReusableSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ScriptTask;
 import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
+import org.kie.workbench.common.stunner.bpmn.definition.StartCompensationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartConditionalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartEscalationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
@@ -54,6 +65,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
 import org.kie.workbench.common.stunner.bpmn.factory.BPMNGraphFactory;
 import org.kie.workbench.common.stunner.bpmn.qualifiers.BPMN;
 import org.kie.workbench.common.stunner.core.definition.annotation.DefinitionSet;
+import org.kie.workbench.common.stunner.core.definition.annotation.SvgNodeId;
 import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
 import org.kie.workbench.common.stunner.core.rule.annotation.Occurrences;
@@ -75,17 +87,27 @@ import org.kie.workbench.common.stunner.core.rule.annotation.Occurrences;
                 StartSignalEvent.class,
                 StartTimerEvent.class,
                 StartErrorEvent.class,
+                StartConditionalEvent.class,
+                StartEscalationEvent.class,
+                StartCompensationEvent.class,
                 EndNoneEvent.class,
                 EndSignalEvent.class,
                 EndMessageEvent.class,
                 EndTerminateEvent.class,
                 EndErrorEvent.class,
+                EndEscalationEvent.class,
+                EndCompensationEvent.class,
                 IntermediateTimerEvent.class,
                 IntermediateMessageEventCatching.class,
                 IntermediateSignalEventCatching.class,
                 IntermediateSignalEventThrowing.class,
                 IntermediateErrorEventCatching.class,
+                IntermediateEscalationEvent.class,
+                IntermediateCompensationEvent.class,
                 IntermediateMessageEventThrowing.class,
+                IntermediateConditionalEvent.class,
+                IntermediateEscalationEventThrowing.class,
+                IntermediateCompensationEventThrowing.class,
                 ParallelGateway.class,
                 ExclusiveGateway.class,
                 InclusiveGateway.class,
@@ -94,7 +116,8 @@ import org.kie.workbench.common.stunner.core.rule.annotation.Occurrences;
                 EventSubprocess.class,
                 AdHocSubprocess.class,
                 MultipleInstanceSubprocess.class,
-                SequenceFlow.class
+                SequenceFlow.class,
+                Association.class
         },
         builder = BPMNDefinitionSet.BPMNDefinitionSetBuilder.class
 )
@@ -104,6 +127,9 @@ import org.kie.workbench.common.stunner.core.rule.annotation.Occurrences;
 @Occurrences(role = "Endevents_all", min = 1)
 public class BPMNDefinitionSet {
 
+    @SvgNodeId
+    public static final String SVG_BPMN_ID = "bpmn2nodeid";
+
     public BPMNDefinitionSet() {
     }
 
