@@ -71,6 +71,7 @@ public abstract class BaseEndEvent implements BPMNViewDefinition,
 
     protected void initLabels() {
         labels.add("all");
+        labels.add("lane_child");
         labels.add("sequence_end");
         labels.add("to_task_event");
         labels.add("from_task_event");
@@ -143,11 +144,12 @@ public abstract class BaseEndEvent implements BPMNViewDefinition,
 
     @Override
     public int hashCode() {
-        return HashUtil.combineHashCodes(general.hashCode(),
-                                         backgroundSet.hashCode(),
-                                         fontSet.hashCode(),
-                                         dimensionsSet.hashCode(),
-                                         labels.hashCode());
+        return HashUtil.combineHashCodes(Objects.hashCode(getClass()),
+                                         Objects.hashCode(general),
+                                         Objects.hashCode(backgroundSet),
+                                         Objects.hashCode(fontSet),
+                                         Objects.hashCode(dimensionsSet),
+                                         Objects.hashCode(labels));
     }
 
     @Override
