@@ -13,44 +13,43 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.processes;
 
 import org.eclipse.bpmn2.SubProcess;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.NodeMatch;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.Result;
-import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.ConverterFactory;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.BaseConverterFactory;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.DefinitionsBuildingContext;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.AdHocSubProcessPropertyWriter;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.MultipleInstanceSubProcessPropertyWriter;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.PropertyWriterFactory;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.SubProcessPropertyWriter;
-import org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNViewDefinition;
+import org.kie.workbench.common.stunner.bpmn.definition.BaseAdHocSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.EventSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.MultipleInstanceSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.subProcess.execution.EmbeddedSubprocessExecutionSet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.subProcess.execution.EventSubprocessExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.task.BaseAdHocSubprocessTaskExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceSubprocessTaskExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.BaseProcessData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
 import static org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.Factories.bpmn2;
 
-public class SubProcessConverter extends AbstractProcessConverter {
+public class SubProcessConverter extends ProcessConverterDelegate {
 
     private final DefinitionsBuildingContext context;
     private final PropertyWriterFactory propertyWriterFactory;
 
-    public SubProcessConverter(
-            DefinitionsBuildingContext context,
-            PropertyWriterFactory propertyWriterFactory,
-            ConverterFactory converterFactory) {
-
+    public SubProcessConverter(DefinitionsBuildingContext context,
+                               PropertyWriterFactory propertyWriterFactory,
+                               BaseConverterFactory converterFactory) {
         super(converterFactory);
         this.context = context;
         this.propertyWriterFactory = propertyWriterFactory;
@@ -61,7 +60,7 @@ public class SubProcessConverter extends AbstractProcessConverter {
                 NodeMatch.fromNode(BaseSubprocess.class, SubProcessPropertyWriter.class)
                         .when(EmbeddedSubprocess.class, this::convertEmbeddedSubprocessNode)
                         .when(EventSubprocess.class, this::convertEventSubprocessNode)
-                        .when(AdHocSubprocess.class, this::convertAdHocSubprocessNode)
+                        .when(BaseAdHocSubprocess.class, this::convertAdHocSubprocessNode)
                         .when(MultipleInstanceSubprocess.class, this::convertMultipleInstanceSubprocessNode)
                         .ignore(BPMNViewDefinition.class)
                         .apply(node);
@@ -106,27 +105,27 @@ public class SubProcessConverter extends AbstractProcessConverter {
 
         p.setSimulationSet(definition.getSimulationSet());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
 
         return p;
     }
 
-    private SubProcessPropertyWriter convertAdHocSubprocessNode(Node<View<AdHocSubprocess>, ?> n) {
+    protected SubProcessPropertyWriter convertAdHocSubprocessNode(Node<View<BaseAdHocSubprocess>, ?> n) {
         org.eclipse.bpmn2.AdHocSubProcess process = bpmn2.createAdHocSubProcess();
         process.setId(n.getUUID());
 
         AdHocSubProcessPropertyWriter p = propertyWriterFactory.of(process);
-        AdHocSubprocess definition = n.getContent().getDefinition();
+        BaseAdHocSubprocess definition = n.getContent().getDefinition();
 
         BPMNGeneralSet general = definition.getGeneral();
 
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
-        ProcessData processData = definition.getProcessData();
+        BaseProcessData processData = definition.getProcessData();
         p.setProcessVariables(processData.getProcessVariables());
 
-        AdHocSubprocessTaskExecutionSet executionSet = definition.getExecutionSet();
+        BaseAdHocSubprocessTaskExecutionSet executionSet = definition.getExecutionSet();
         p.setAdHocCompletionCondition(executionSet.getAdHocCompletionCondition());
         p.setAdHocOrdering(executionSet.getAdHocOrdering());
         p.setOnEntryAction(executionSet.getOnEntryAction());
@@ -134,7 +133,7 @@ public class SubProcessConverter extends AbstractProcessConverter {
 
         p.setSimulationSet(definition.getSimulationSet());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
 
         return p;
     }
@@ -155,9 +154,12 @@ public class SubProcessConverter extends AbstractProcessConverter {
         ProcessData processData = definition.getProcessData();
         p.setProcessVariables(processData.getProcessVariables());
 
+        EventSubprocessExecutionSet executionSet = definition.getExecutionSet();
+        p.setAsync(executionSet.getIsAsync().getValue());
+
         p.setSimulationSet(definition.getSimulationSet());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
 
         return p;
     }
@@ -184,7 +186,7 @@ public class SubProcessConverter extends AbstractProcessConverter {
         p.setProcessVariables(processData.getProcessVariables());
 
         p.setSimulationSet(definition.getSimulationSet());
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
         return p;
     }
 }
\ No newline at end of file
