@@ -88,7 +88,7 @@ public class TaskConverter {
 
         p.setSimulationSet(definition.getSimulationSet());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
         return p;
     }
 
@@ -109,6 +109,8 @@ public class TaskConverter {
         p.setTaskName(executionSet.getTaskName().getValue());
         p.setActors(executionSet.getActors());
         p.setAssignmentsInfo(executionSet.getAssignmentsinfo());
+        p.setReassignments(executionSet.getReassignmentsInfo());
+        p.setNotifications(executionSet.getNotificationsInfo());
         p.setSkippable(executionSet.getSkippable().getValue());
         p.setGroupId(executionSet.getGroupid().getValue());
         p.setSubject(executionSet.getSubject().getValue());
@@ -132,7 +134,7 @@ public class TaskConverter {
         p.setContent(executionSet.getContent().getValue());
         p.setSLADueDate(executionSet.getSlaDueDate().getValue());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
 
         return p;
     }
@@ -170,7 +172,7 @@ public class TaskConverter {
 
         p.setSimulationSet(definition.getSimulationSet());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
         return p;
     }
 
@@ -192,7 +194,7 @@ public class TaskConverter {
 
         p.setSimulationSet(definition.getSimulationSet());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
         return p;
     }
 
@@ -206,7 +208,7 @@ public class TaskConverter {
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
-        p.setBounds(n.getContent().getBounds());
+        p.setAbsoluteBounds(n);
 
         p.setSimulationSet(definition.getSimulationSet());
         return p;
