@@ -24,6 +24,7 @@ import java.util.Set;
 
 import com.google.gwtmockito.GwtMock;
 import com.google.gwtmockito.GwtMockito;
+import org.gwtbootstrap3.client.ui.Button;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -35,8 +36,17 @@ import org.mockito.Captor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyBoolean;
+import static org.mockito.Mockito.anyList;
+import static org.mockito.Mockito.anySet;
+import static org.mockito.Mockito.doCallRealMethod;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ActivityDataIOEditorViewImplTest {
@@ -50,6 +60,9 @@ public class ActivityDataIOEditorViewImplTest {
     @Captor
     private ArgumentCaptor<List<AssignmentRow>> listAssignmentCaptor;
 
+    @GwtMock
+    private Button btnSave;
+
     @GwtMock
     private ActivityDataIOEditorViewImpl view;
 
@@ -65,6 +78,7 @@ public class ActivityDataIOEditorViewImplTest {
         GwtMockito.initMocks(this);
         view.inputAssignmentsWidget = inputAssignmentsWidget;
         view.outputAssignmentsWidget = outputAssignmentsWidget;
+        view.btnSave = btnSave;
         view.presenter = presenter;
         doCallRealMethod().when(view).setInputAssignmentRows(any(List.class));
         doCallRealMethod().when(view).setOutputAssignmentRows(any(List.class));
@@ -79,6 +93,7 @@ public class ActivityDataIOEditorViewImplTest {
         doCallRealMethod().when(view).setOutputAssignmentsVisibility(anyBoolean());
         doCallRealMethod().when(view).getInputAssignmentData();
         doCallRealMethod().when(view).getOutputAssignmentData();
+        doCallRealMethod().when(view).setReadOnly(anyBoolean());
         rows = new ArrayList<AssignmentRow>();
         rows.add(new AssignmentRow("varName",
                                    null,
@@ -249,4 +264,26 @@ public class ActivityDataIOEditorViewImplTest {
         assertEquals("varName2",
                      listAssignmentCaptor.getValue().get(1).getProcessVar());
     }
+
+    @Test
+    public void testSetReadOnlyTrue() {
+        view.setReadOnly(true);
+        verify(btnSave,
+               times(1)).setEnabled(false);
+        verify(inputAssignmentsWidget,
+               times(1)).setReadOnly(true);
+        verify(outputAssignmentsWidget,
+               times(1)).setReadOnly(true);
+    }
+
+    @Test
+    public void testSetReadOnlyFalse() {
+        view.setReadOnly(false);
+        verify(btnSave,
+               times(1)).setEnabled(true);
+        verify(inputAssignmentsWidget,
+               times(1)).setReadOnly(false);
+        verify(outputAssignmentsWidget,
+               times(1)).setReadOnly(false);
+    }
 }
