@@ -17,7 +17,7 @@
 package org.kie.workbench.common.stunner.bpmn.client.forms.fields.variablesEditor;
 
 import com.google.gwt.core.client.GWT;
-import com.google.gwt.event.dom.client.BlurHandler;
+import com.google.gwt.event.dom.client.ChangeHandler;
 import com.google.gwt.event.dom.client.KeyDownHandler;
 import com.google.gwt.regexp.shared.RegExp;
 import com.google.gwtmockito.GwtMock;
@@ -133,7 +133,7 @@ public class VariableListItemWidgetTest {
         verify(customDataType,
                times(1)).addKeyDownHandler(any(KeyDownHandler.class));
         verify(name,
-               times(1)).addBlurHandler(any(BlurHandler.class));
+               times(1)).addChangeHandler(any(ChangeHandler.class));
     }
 
     @Test
