@@ -16,19 +16,22 @@
 
 package org.kie.workbench.common.stunner.cm.client.canvas;
 
-import com.ait.lienzo.client.core.shape.MultiPath;
+import java.util.Collections;
+import java.util.Optional;
+import java.util.function.Consumer;
+
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
-import org.kie.workbench.common.stunner.cm.client.shape.ActivityShape;
-import org.kie.workbench.common.stunner.cm.client.shape.def.CaseManagementTaskShapeDef;
-import org.kie.workbench.common.stunner.cm.client.shape.view.ActivityView;
+import org.kie.workbench.common.stunner.bpmn.definition.BPMNViewDefinition;
+import org.kie.workbench.common.stunner.cm.client.shape.CaseManagementShape;
+import org.kie.workbench.common.stunner.cm.client.shape.view.CaseManagementShapeView;
+import org.kie.workbench.common.stunner.cm.definition.CaseManagementDiagram;
 import org.kie.workbench.common.stunner.core.client.api.ClientDefinitionManager;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.Layer;
+import org.kie.workbench.common.stunner.core.client.canvas.Transform;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProvider;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProviderFactory;
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementAddedEvent;
@@ -36,9 +39,8 @@ import org.kie.workbench.common.stunner.core.client.canvas.event.registration.Ca
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementUpdatedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementsClearEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
-import org.kie.workbench.common.stunner.core.client.service.ClientFactoryService;
 import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
-import org.kie.workbench.common.stunner.core.client.shape.impl.AbstractElementShape;
+import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.definition.adapter.AdapterManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
 import org.kie.workbench.common.stunner.core.definition.adapter.PropertyAdapter;
@@ -46,22 +48,33 @@ import org.kie.workbench.common.stunner.core.definition.property.PropertyMetaTyp
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
+import org.kie.workbench.common.stunner.core.graph.content.Bounds;
+import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewImpl;
 import org.kie.workbench.common.stunner.core.graph.impl.NodeImpl;
 import org.kie.workbench.common.stunner.core.graph.processing.index.GraphIndexBuilder;
+import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.kie.workbench.common.stunner.core.graph.processing.index.MutableIndex;
+import org.kie.workbench.common.stunner.core.graph.processing.index.map.MapIndex;
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
-import org.kie.workbench.common.stunner.shapes.client.view.PictureShapeView;
 import org.mockito.Mock;
 import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Matchers.anyDouble;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyObject;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class CaseManagementCanvasHandlerTest {
@@ -69,9 +82,6 @@ public class CaseManagementCanvasHandlerTest {
     @Mock
     private ClientDefinitionManager clientDefinitionManager;
 
-    @Mock
-    private ClientFactoryService clientFactoryServices;
-
     @Mock
     private RuleManager ruleManager;
 
@@ -115,10 +125,13 @@ public class CaseManagementCanvasHandlerTest {
     private CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
 
     @Mock
-    private CaseManagementCanvasPresenter canvas;
+    private CaseManagementCanvas canvas;
 
     @Mock
-    private Layer layer;
+    private Transform transform;
+
+    private static final double X = 10.0d;
+    private static final double Y = 20.0d;
 
     private CaseManagementCanvasHandler handler;
 
@@ -126,7 +139,6 @@ public class CaseManagementCanvasHandlerTest {
     @SuppressWarnings("unchecked")
     public void setup() {
         this.handler = new CaseManagementCanvasHandler(clientDefinitionManager,
-                                                       clientFactoryServices,
                                                        ruleManager,
                                                        graphUtils,
                                                        indexBuilder,
@@ -138,8 +150,11 @@ public class CaseManagementCanvasHandlerTest {
                                                        canvasElementsClearEvent,
                                                        canvasCommandFactory);
         this.handler.handle(canvas);
-        when(canvas.getLayer()).thenReturn(layer);
         when(textPropertyProviderFactory.getProvider(any(Element.class))).thenReturn(textPropertyProvider);
+
+        when((canvas.getTransform())).thenReturn(transform);
+        when(transform.transform(anyDouble(), anyDouble())).thenAnswer(
+                invocation -> new Point2D(invocation.getArgumentAt(0, Double.class), invocation.getArgumentAt(1, Double.class)));
     }
 
     @Test
@@ -155,9 +170,9 @@ public class CaseManagementCanvasHandlerTest {
     @Test
     @SuppressWarnings("unchecked")
     public void checkRegisterRenderableShapes() {
-        final ActivityShape shape = makeShape();
-        final Node<View<BPMNDefinition>, Edge> node = makeNode("uuid",
-                                                               shape);
+        final CaseManagementShape shape = makeShape();
+        final Node<View<BPMNViewDefinition>, Edge> node = makeNode("uuid",
+                                                                   shape);
 
         handler.register(shape,
                          node,
@@ -165,30 +180,21 @@ public class CaseManagementCanvasHandlerTest {
 
         verify(canvas,
                times(1)).addShape(eq(shape));
-        verify(canvas,
-               times(1)).draw();
     }
 
     @SuppressWarnings("unchecked")
-    private ActivityShape makeShape() {
-        final CaseManagementTaskShapeDef shapeDef = new CaseManagementTaskShapeDef();
-        final ActivityView shapeView = new ActivityView(10.0,
-                                                        20.0);
-        final ActivityShape shape = new ActivityShape(shapeDef,
-                                                      new PictureShapeView(new MultiPath()),
-                                                      shapeView);
-        return shape;
+    private CaseManagementShape makeShape() {
+        final CaseManagementShapeView shapeView = mock(CaseManagementShapeView.class);
+        return new CaseManagementShape(shapeView);
     }
 
     @SuppressWarnings("unchecked")
-    private Node<View<BPMNDefinition>, Edge> makeNode(final String uuid,
-                                                      final AbstractElementShape shape) {
-        final Node<View<BPMNDefinition>, Edge> node = new NodeImpl<>(uuid);
-        node.setContent(new ViewImpl(shape.getShapeDefinition(),
-                                     new BoundsImpl(new BoundImpl(0.0,
-                                                                  0.0),
-                                                    new BoundImpl(10.0,
-                                                                  20.0))));
+    private Node<View<BPMNViewDefinition>, Edge> makeNode(final String uuid,
+                                                          final CaseManagementShape shape) {
+        final Node<View<BPMNViewDefinition>, Edge> node = new NodeImpl<>(uuid);
+        node.setContent(new ViewImpl(new CaseManagementDiagram(),
+                                     Bounds.create(0d, 0d, 10d, 20d)));
+        shape.setUUID(uuid);
         when(canvas.getShape(eq(uuid))).thenReturn(shape);
         when(clientDefinitionManager.adapters()).thenReturn(adapterManager);
         when(adapterManager.forDefinition()).thenReturn(definitionAdapter);
@@ -201,9 +207,9 @@ public class CaseManagementCanvasHandlerTest {
 
     @Test
     public void checkDeregisterRenderableShapes() {
-        final ActivityShape shape = makeShape();
-        final Node<View<BPMNDefinition>, Edge> node = makeNode("uuid",
-                                                               shape);
+        final CaseManagementShape shape = makeShape();
+        final Node<View<BPMNViewDefinition>, Edge> node = makeNode("uuid",
+                                                                   shape);
 
         handler.deregister(shape,
                            node,
@@ -211,13 +217,11 @@ public class CaseManagementCanvasHandlerTest {
 
         verify(canvas,
                times(1)).deleteShape(eq(shape));
-        verify(canvas,
-               times(1)).draw();
     }
 
     @Test
     public void checkAddShapeRenderableShapes() {
-        final ActivityShape shape = makeShape();
+        final CaseManagementShape shape = makeShape();
 
         handler.addShape(shape);
 
@@ -228,12 +232,12 @@ public class CaseManagementCanvasHandlerTest {
     @Test
     @SuppressWarnings("unchecked")
     public void checkAddChildRenderableShapes() {
-        final ActivityShape parentShape = makeShape();
-        final ActivityShape childShape = makeShape();
-        final Node<View<BPMNDefinition>, Edge> parentNode = makeNode("parent",
-                                                                     parentShape);
-        final Node<View<BPMNDefinition>, Edge> childNode = makeNode("child",
-                                                                    childShape);
+        final CaseManagementShape parentShape = makeShape();
+        final CaseManagementShape childShape = makeShape();
+        final Node<View<BPMNViewDefinition>, Edge> parentNode = makeNode("parent",
+                                                                         parentShape);
+        final Node<View<BPMNViewDefinition>, Edge> childNode = makeNode("child",
+                                                                        childShape);
 
         handler.register(parentShape,
                          parentNode,
@@ -246,21 +250,19 @@ public class CaseManagementCanvasHandlerTest {
                          childNode);
 
         verify(canvas,
-               times(1)).addChildShape(eq(parentShape),
-                                       eq(childShape));
-        verify(layer,
-               never()).addShape(eq(childShape));
+               times(1)).addChild(eq(parentShape),
+                                  eq(childShape));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void checkAddChildRenderableShapesAtIndex() {
-        final ActivityShape parentShape = makeShape();
-        final ActivityShape childShape = makeShape();
-        final Node<View<BPMNDefinition>, Edge> parentNode = makeNode("parent",
-                                                                     parentShape);
-        final Node<View<BPMNDefinition>, Edge> childNode = makeNode("child",
-                                                                    childShape);
+        final CaseManagementShape parentShape = makeShape();
+        final CaseManagementShape childShape = makeShape();
+        final Node<View<BPMNViewDefinition>, Edge> parentNode = makeNode("parent",
+                                                                         parentShape);
+        final Node<View<BPMNViewDefinition>, Edge> childNode = makeNode("child",
+                                                                        childShape);
 
         handler.register(parentShape,
                          parentNode,
@@ -274,16 +276,14 @@ public class CaseManagementCanvasHandlerTest {
                          0);
 
         verify(canvas,
-               times(1)).addChildShape(eq(parentShape),
-                                       eq(childShape),
-                                       eq(0));
-        verify(layer,
-               never()).addShape(eq(childShape));
+               times(1)).addChild(eq(parentShape),
+                                  eq(childShape),
+                                  eq(0));
     }
 
     @Test
     public void checkRemoveShapeRenderableShapes() {
-        final ActivityShape shape = makeShape();
+        final CaseManagementShape shape = makeShape();
 
         handler.removeShape(shape);
 
@@ -294,12 +294,12 @@ public class CaseManagementCanvasHandlerTest {
     @Test
     @SuppressWarnings("unchecked")
     public void checkRemoveChildRenderableShapes() {
-        final ActivityShape parentShape = makeShape();
-        final ActivityShape childShape = makeShape();
-        final Node<View<BPMNDefinition>, Edge> parentNode = makeNode("parent",
-                                                                     parentShape);
-        final Node<View<BPMNDefinition>, Edge> childNode = makeNode("child",
-                                                                    childShape);
+        final CaseManagementShape parentShape = makeShape();
+        final CaseManagementShape childShape = makeShape();
+        final Node<View<BPMNViewDefinition>, Edge> parentNode = makeNode("parent",
+                                                                         parentShape);
+        final Node<View<BPMNViewDefinition>, Edge> childNode = makeNode("child",
+                                                                        childShape);
 
         handler.register(parentShape,
                          parentNode,
@@ -314,26 +314,20 @@ public class CaseManagementCanvasHandlerTest {
                             childNode);
 
         verify(canvas,
-               times(1)).deleteChildShape(parentShape,
-                                          childShape);
-        verify(layer,
-               never()).removeShape(childShape);
+               times(1)).deleteChild(parentShape,
+                                     childShape);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void checkApplyElementMutationRenderableShapes() {
-        final ActivityShape shape = spy(makeShape());
-        final Node<View<BPMNDefinition>, Edge> node = makeNode("uuid",
-                                                               shape);
+        final CaseManagementShape shape = spy(makeShape());
+        final Node<View<BPMNViewDefinition>, Edge> node = makeNode("uuid",
+                                                                   shape);
         final MutationContext mutationContext = mock(MutationContext.class);
-        doNothing().when(shape).applyPosition(eq(node),
-                                              eq(mutationContext));
-        doNothing().when(shape).applyProperties(eq(node),
-                                                eq(mutationContext));
-        doNothing().when(shape).applyTitle(anyString(),
-                                           any(Node.class),
-                                           eq(mutationContext));
+
+        final String name = "mockName";
+        when(textPropertyProvider.getText(eq(node))).thenReturn(name);
 
         handler.applyElementMutation(shape,
                                      node,
@@ -341,49 +335,150 @@ public class CaseManagementCanvasHandlerTest {
                                      true,
                                      mutationContext);
 
+        verify(shape.getShapeView(),
+               times(1)).refresh();
+
+        verify((CaseManagementShapeView) shape.getShapeView(),
+               times(1)).setLabel(eq(name));
+
         verify(shape,
-               times(1)).applyPosition(eq(node),
-                                       eq(mutationContext));
+               times(1)).beforeDraw();
+
         verify(shape,
-               times(1)).applyProperties(eq(node),
-                                         eq(mutationContext));
-        verify(canvas,
-               times(1)).draw();
+               times(1)).afterDraw();
+
+        verify(canvasElementUpdatedEvent,
+               times(1)).fire(any());
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void checkApplyShapeElementMutationRenderableShapes() {
-        final ActivityShape shape = spy(makeShape());
-        final Node<View<BPMNDefinition>, Edge> node = makeNode("uuid",
-                                                               shape);
+        final CaseManagementShape shape = spy(makeShape());
+        final Node<View<BPMNViewDefinition>, Edge> node = makeNode("uuid",
+                                                                   shape);
         final MutationContext mutationContext = mock(MutationContext.class);
-        doNothing().when(shape).applyPosition(eq(node),
-                                              eq(mutationContext));
-        doNothing().when(shape).applyProperties(eq(node),
-                                                eq(mutationContext));
-        doNothing().when(shape).applyTitle(anyString(),
-                                           any(Node.class),
-                                           eq(mutationContext));
+
+        final String name = "mockName";
+        when(textPropertyProvider.getText(eq(node))).thenReturn(name);
 
         handler.register(shape,
                          node,
                          true);
-        verify(canvas,
-               times(1)).draw();
-
         handler.applyElementMutation(node,
                                      true,
                                      true,
                                      mutationContext);
 
+        verify(shape.getShapeView(),
+               times(1)).refresh();
+
+        verify((CaseManagementShapeView) shape.getShapeView(),
+               times(1)).setLabel(eq(name));
+
         verify(shape,
-               times(1)).applyPosition(eq(node),
-                                       eq(mutationContext));
+               times(1)).beforeDraw();
+
         verify(shape,
-               times(1)).applyProperties(eq(node),
-                                         eq(mutationContext));
-        verify(canvas,
-               times(2)).draw();
+               times(1)).afterDraw();
+
+        verify(canvasElementUpdatedEvent,
+               times(1)).fire(any());
+    }
+
+    @SuppressWarnings("unchecked")
+    private Node<View<BPMNViewDefinition>, Edge> mockCanvasDiagramNode(String uuid,
+                                                                       Consumer<CaseManagementShape> canvasMockCallback) {
+        final CaseManagementShape shape = spy(makeShape());
+        final Node<View<BPMNViewDefinition>, Edge> node = makeNode(uuid, shape);
+        canvasMockCallback.accept(shape);
+
+        final MapIndex index = mock(MapIndex.class);
+        when(index.getNode(eq(uuid))).thenReturn(node);
+
+        this.handler = new CaseManagementCanvasHandler(clientDefinitionManager,
+                                                       ruleManager,
+                                                       graphUtils,
+                                                       indexBuilder,
+                                                       shapeManager,
+                                                       textPropertyProviderFactory,
+                                                       canvasElementAddedEvent,
+                                                       canvasElementRemovedEvent,
+                                                       canvasElementUpdatedEvent,
+                                                       canvasElementsClearEvent,
+                                                       canvasCommandFactory) {
+            @Override
+            public Index<?, ?> getGraphIndex() {
+                return index;
+            }
+        };
+        this.handler.handle(canvas);
+
+        return node;
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void checkGetDiagramNode() throws Exception {
+        final Node<View<BPMNViewDefinition>, Edge> node =
+                mockCanvasDiagramNode("uuid",
+                                      shape -> when(canvas.getShapes()).thenReturn(Collections.<Shape>singletonList(shape)));
+
+        final Optional<Node<View<?>, Edge>> root = handler.getDiagramNode();
+
+        assertTrue(root.isPresent());
+        assertEquals(node, root.get());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGetElementAt_empty() throws Exception {
+        when(canvas.getShapeAt(eq(X), eq(Y))).thenReturn(Optional.empty());
+        when(canvas.getShapes()).thenReturn(Collections.emptyList());
+
+        final Optional<Element> node = handler.getElementAt(X, Y);
+
+        verify(transform, times(1)).transform(eq(X), eq(Y));
+        verify(canvas, times(1)).getShapeAt(eq(X), eq(Y));
+        verify(canvas, times(1)).getShapes();
+
+        assertFalse(node.isPresent());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGetElementAt_element() throws Exception {
+        final Node<View<BPMNViewDefinition>, Edge> node =
+                mockCanvasDiagramNode("uuid",
+                                      shape -> when(canvas.getShapeAt(eq(X), eq(Y)))
+                                              .thenReturn(Optional.of(shape)));
+        when(canvas.getShapes()).thenReturn(Collections.emptyList());
+
+        final Optional<Element> result = handler.getElementAt(X, Y);
+
+        verify(transform, times(1)).transform(eq(X), eq(Y));
+        verify(canvas, times(1)).getShapeAt(eq(X), eq(Y));
+        verify(canvas, never()).getShapes();
+
+        assertTrue(result.isPresent());
+        assertEquals(node, result.get());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGetElementAt_root() throws Exception {
+        when(canvas.getShapeAt(eq(X), eq(Y))).thenReturn(Optional.empty());
+        final Node<View<BPMNViewDefinition>, Edge> root =
+                mockCanvasDiagramNode("uuid",
+                                      shape -> when(canvas.getShapes()).thenReturn(Collections.<Shape>singletonList(shape)));
+
+        final Optional<Element> node = handler.getElementAt(X, Y);
+
+        verify(transform, times(1)).transform(eq(X), eq(Y));
+        verify(canvas, times(1)).getShapeAt(eq(X), eq(Y));
+        verify(canvas, times(1)).getShapes();
+
+        assertTrue(node.isPresent());
+        assertEquals(root, node.get());
     }
 }
