@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.cm.project.client.editor;
 
+import java.util.function.Consumer;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -149,8 +151,8 @@ public class CaseManagementDiagramEditor extends AbstractProjectDiagramEditor<Ca
     }
 
     @WorkbenchMenu
-    public Menus getMenus() {
-        return super.getMenus();
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        super.getMenus(menusConsumer);
     }
 
     @WorkbenchPartView
