@@ -25,8 +25,10 @@ import javax.inject.Inject;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.user.client.ui.IsWidget;
+import elemental2.promise.Promise;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
@@ -36,12 +38,16 @@ import org.jboss.errai.common.client.api.Caller;
 import org.kie.workbench.common.widgets.client.callbacks.CommandBuilder;
 import org.kie.workbench.common.widgets.client.callbacks.CommandDrivenErrorCallback;
 import org.kie.workbench.common.widgets.client.docks.DefaultEditorDock;
+import org.kie.workbench.common.widgets.client.docks.DockPlaceHolderPlace;
+import org.kie.workbench.common.widgets.client.docks.DockPlaceHolderView;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.source.ViewDRLSourceWidget;
 import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.uberfire.backend.vfs.ObservablePath;
+import org.uberfire.client.mvp.AbstractWorkbenchActivity;
 import org.uberfire.client.mvp.PerspectiveManager;
+import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.client.workbench.events.AbstractPlaceEvent;
 import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
 import org.uberfire.client.workbench.events.PlaceHiddenEvent;
@@ -68,41 +74,17 @@ public abstract class KieEditor<T>
         extends BaseEditor<T, Metadata>
         implements KieEditorWrapperView.KieEditorWrapperPresenter {
 
+    //This implementation always permits closure as something went wrong loading the Editor's content
+    private final MayCloseHandler EXCEPTION_MAY_CLOSE_HANDLER = new MayCloseHandler() {
+        @Override
+        public boolean mayClose(final Object object) {
+            return true;
+        }
+    };
     @Inject
     protected KieEditorWrapperView kieView;
     @Inject
     protected OverviewWidgetPresenter overviewWidget;
-
-    @Inject
-    protected FileMenuBuilder fileMenuBuilder;
-
-    @Inject
-    protected WorkspaceProjectContext workbenchContext;
-    @Inject
-    protected SavePopUpPresenter savePopUpPresenter;
-    @Inject
-    protected DeletePopUpPresenter deletePopUpPresenter;
-    @Inject
-    protected RenamePopUpPresenter renamePopUpPresenter;
-    @Inject
-    protected CopyPopUpPresenter copyPopUpPresenter;
-
-    @Inject
-    protected ProjectController projectController;
-
-    @Inject
-    protected AssetUpdateValidator assetUpdateValidator;
-
-    @Inject
-    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
-
-    protected Metadata metadata;
-    @Inject
-    protected DefaultEditorDock docks;
-    @Inject
-    protected PerspectiveManager perspectiveManager;
-    private ViewDRLSourceWidget sourceWidget;
-
     //The default implementation delegates to the HashCode comparison in BaseEditor
     private final MayCloseHandler DEFAULT_MAY_CLOSE_HANDLER = new MayCloseHandler() {
 
@@ -115,14 +97,30 @@ public abstract class KieEditor<T>
             }
         }
     };
-    //This implementation always permits closure as something went wrong loading the Editor's content
-    private final MayCloseHandler EXCEPTION_MAY_CLOSE_HANDLER = new MayCloseHandler() {
-        @Override
-        public boolean mayClose(final Object object) {
-            return true;
-        }
-    };
-
+    @Inject
+    protected FileMenuBuilder fileMenuBuilder;
+    @Inject
+    protected WorkspaceProjectContext workbenchContext;
+    @Inject
+    protected SavePopUpPresenter savePopUpPresenter;
+    @Inject
+    protected DeletePopUpPresenter deletePopUpPresenter;
+    @Inject
+    protected RenamePopUpPresenter renamePopUpPresenter;
+    @Inject
+    protected CopyPopUpPresenter copyPopUpPresenter;
+    @Inject
+    protected ProjectController projectController;
+    @Inject
+    protected AssetUpdateValidator assetUpdateValidator;
+    @Inject
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+    protected Metadata metadata;
+    @Inject
+    protected DefaultEditorDock docks;
+    @Inject
+    protected PerspectiveManager perspectiveManager;
+    private ViewDRLSourceWidget sourceWidget;
     private MayCloseHandler mayCloseHandler = DEFAULT_MAY_CLOSE_HANDLER;
 
     protected KieEditor() {
@@ -312,15 +310,24 @@ public abstract class KieEditor<T>
      * If you want to customize the menu override this method.
      */
     @Override
-    protected void makeMenuBar() {
-        if (canUpdateProject()) {
-            addSave(fileMenuBuilder);
-            addCopy(fileMenuBuilder);
-            addRename(fileMenuBuilder);
-            addDelete(fileMenuBuilder);
+    protected Promise<Void> makeMenuBar() {
+        if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
+            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+            return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
+                if (canUpdateProject) {
+                    addSave(fileMenuBuilder);
+                    addCopy(fileMenuBuilder);
+                    addRename(fileMenuBuilder);
+                    addDelete(fileMenuBuilder);
+                }
+                addDownloadMenuItem(fileMenuBuilder);
+                addCommonActions(fileMenuBuilder);
+
+                return promises.resolve();
+            });
         }
-        addDownloadMenuItem(fileMenuBuilder);
-        addCommonActions(fileMenuBuilder);
+
+        return promises.resolve();
     }
 
     public void addDownloadMenuItem(final FileMenuBuilder fileMenuBuilder) {
@@ -406,13 +413,6 @@ public abstract class KieEditor<T>
                                                 NotificationEvent.NotificationType.ERROR));
     }
 
-    protected boolean canUpdateProject() {
-        return workbenchContext
-                .getActiveWorkspaceProject()
-                .map(activeProject -> projectController.canUpdateProject(activeProject))
-                .orElse(true);
-    }
-
     @Override
     protected void buildMenuBar() {
         if (fileMenuBuilder != null) {
@@ -483,12 +483,33 @@ public abstract class KieEditor<T>
 
     }
 
+    protected void registerDock(final String id,
+                                final IsWidget widget) {
+
+        final DockPlaceHolderPlace placeRequest = new DockPlaceHolderPlace(id);
+        placeManager.registerOnOpenCallback(placeRequest, () -> {
+            if (getDockPresenter(placeRequest).isPresent()) {
+                getDockPresenter(placeRequest).get().setWidget(widget);
+            }
+        });
+    }
+
+    private Optional<DockPlaceHolderView> getDockPresenter(final PlaceRequest placeRequest) {
+        if (PlaceStatus.OPEN.equals(placeManager.getStatus(placeRequest))) {
+            final AbstractWorkbenchActivity panelActivity = (AbstractWorkbenchActivity) placeManager.getActivity(placeRequest);
+            return Optional.of((DockPlaceHolderView) panelActivity.getWidget());
+        } else {
+            return Optional.empty();
+        }
+    }
+
     @Override
     public void onOverviewSelected() {
     }
 
     @Override
     public void onSourceTabSelected() {
+
     }
 
     /**
